@@ -66,11 +66,11 @@ enum {
   ACTION_HELP_DEVELOPMENT,
   ACTION_HELP_ABOUT,
 #define ACTION_HELP_LAST    ACTION_HELP_ABOUT
-  ACTION_URL_HELP_DESK,
   ACTION_URL_BEAST_SITE,
+  ACTION_URL_HELP_DESK,
+  ACTION_URL_REPORT_BUG,
   ACTION_URL_ONLINE_SYNTHESIZERS,
   ACTION_URL_ONLINE_DEMOS,
-  ACTION_DEMO_DIALOG_FATAL,
   ACTION_DEMO_DIALOG_ERROR,
   ACTION_DEMO_DIALOG_WARNING,
   ACTION_DEMO_DIALOG_SCRIPT,
@@ -91,7 +91,7 @@ static const GxkStockAction file_open_actions[] = {
     BST_ACTION_CLOSE_PROJECT,   BST_STOCK_CLOSE, },
 };
 static const GxkStockAction file_save_actions[] = {
-  { N_("_Save"),                NULL,           N_("Write project to disk"),
+  { N_("_Save"),                "<ctrl>S",      N_("Write project to disk"),
     BST_ACTION_SAVE_PROJECT,    BST_STOCK_SAVE, },
   { N_("Save _As..."),          NULL,           N_("Write project to a specific file"),
     BST_ACTION_SAVE_PROJECT_AS, BST_STOCK_SAVE_AS, },
@@ -134,7 +134,7 @@ static const GxkStockAction dialog_actions[] = {
 static const GxkStockAction playback_actions[] = {
   { N_("_Play"),                "<ctrl>P",      N_("Play or restart playback of the project"),
     BST_ACTION_START_PLAYBACK,  BST_STOCK_PLAY },
-  { N_("_Stop"),                "<ctrl>S",      N_("Stop playback of the project"),
+  { N_("_Stop"),                "<ctrl>D",      N_("Stop playback of the project"),
     BST_ACTION_STOP_PLAYBACK,  BST_STOCK_STOP },
 };
 static const GxkStockAction project_actions[] = {
@@ -164,10 +164,12 @@ static const GxkStockAction simple_help_actions[] = {
     ACTION_HELP_QUICK_START,    BST_STOCK_HELP },
   { N_("_FAQ..."),              NULL,           N_("Answers to frequently asked questions"),
     ACTION_HELP_FAQ,            BST_STOCK_DOC_FAQ },
+  { N_("_Beast Website..."),    NULL,           N_("Start a web browser pointing to the BEAST website"),
+    ACTION_URL_BEAST_SITE,      BST_STOCK_ONLINE_BEAST_SITE },
   { N_("Online _Help Desk..."), NULL,           N_("Start a web browser pointing to the online help desk at the BEAST website"),
     ACTION_URL_HELP_DESK,       BST_STOCK_ONLINE_HELP_DESK },
-  { N_("_BEAST Website..."),    NULL,           N_("Start a web browser pointing to the BEAST website"),
-    ACTION_URL_BEAST_SITE,      BST_STOCK_ONLINE_BEAST_SITE },
+  { N_("Report a Beast Bug..."),NULL,           N_("Start a web browser with the bug report form for the BEAST bugzilla product"),
+    ACTION_URL_REPORT_BUG,      BST_STOCK_ONLINE_BUGS },
 #if 0
   { N_("_Release Notes..."),    NULL,           N_("Notes and informations about this release cycle"),
     ACTION_HELP_RELEASE_NOTES,  BST_STOCK_DOC_NEWS },
@@ -175,9 +177,9 @@ static const GxkStockAction simple_help_actions[] = {
     ACTION_HELP_PLUGIN_DEVEL,   BST_STOCK_DOC_DEVEL },
   { N_("DSP Engine..."),        NULL,           N_("Technical description of the multi-threaded synthesis engine innards"),
     ACTION_HELP_DSP_ENGINE,     BST_STOCK_DOC_DEVEL },
-#endif
   { N_("Development..."),       NULL,           N_("Provide an overview of development related topics and documents"),
     ACTION_HELP_DEVELOPMENT,    BST_STOCK_DOC_DEVEL },
+#endif
 };
 static const GxkStockAction online_synthesizers[] = {
   { N_("Online Sound Archive..."),  NULL,        N_("Start a web browser pointing to the online sound archive"),
@@ -188,8 +190,6 @@ static const GxkStockAction online_demos[] = {
     ACTION_URL_ONLINE_DEMOS,        BST_STOCK_ONLINE_SOUND_ARCHIVE },
 };
 static const GxkStockAction demo_dialogs[] = {
-  { "Demo Fatal Error Dialog",  NULL,           "Fire up a fatal error dialog for demonstration purposes",
-    ACTION_DEMO_DIALOG_FATAL,   BST_STOCK_ERROR },
   { "Demo Error Dialog",        NULL,           "Fire up an error dialog for demonstration purposes",
     ACTION_DEMO_DIALOG_ERROR,   BST_STOCK_ERROR },
   { "Demo Warning Dialog",      NULL,           "Fire up a warning dialog for demonstration purposes",
@@ -229,6 +229,8 @@ bst_app_init (BstApp *self)
   GtkWidget *widget = GTK_WIDGET (self);
   BseCategorySeq *cseq;
   GxkActionList *al1, *al2;
+
+  self->cookie = g_strdup ("");
   
   g_object_set (self,
                 "name", "BEAST-Application",
@@ -397,6 +399,7 @@ bst_app_finalize (GObject *object)
       g_object_unref (self->ppages);
       self->ppages = NULL;
     }
+  g_free (self->cookie);
   
   G_OBJECT_CLASS (bst_app_parent_class)->finalize (object);
 }
@@ -732,7 +735,7 @@ demo_play_song (gpointer data,
 {
   const gchar *file_name = demo_entries[callback_action - BST_ACTION_LOAD_DEMO_0000].file;
   SfiProxy project = bse_server_use_new_project (BSE_SERVER, file_name);
-  BseErrorType error = bst_project_restore_from_file (project, file_name, TRUE);
+  BseErrorType error = bst_project_restore_from_file (project, file_name, TRUE, TRUE);
   if (error)
     bst_status_eprintf (error, _("Opening project `%s'"), file_name);
   else
@@ -857,10 +860,9 @@ static void
 app_action_exec (gpointer data,
                  gulong   action)
 {
-  static GtkWidget *bst_help_dialogs[ACTION_HELP_LAST - ACTION_HELP_FIRST + 1] = { NULL, };
   static GtkWidget *bst_preferences = NULL;
   BstApp *self = BST_APP (data);
-  gchar *help_file = NULL, *help_title = NULL;
+  const gchar *docs_url = NULL, *docs_title = "";
   GtkWidget *widget = GTK_WIDGET (self);
   
   gxk_status_window_push (widget);
@@ -1058,68 +1060,59 @@ app_action_exec (gpointer data,
       gtk_widget_queue_draw (GTK_WIDGET (self->notebook));
       break;
     case ACTION_HELP_INDEX:
-      help_file = g_strconcat (BST_PATH_DOCS, "/beast-index.markup", NULL);
-      help_title = g_strdup (help_file);
-      goto HELP_DIALOG;
+      docs_url = "html/beast-index.html";
+      docs_title = "BEAST Index";
+      goto BROWSE_LOCAL_URL;
     case ACTION_HELP_FAQ:
-      help_file = g_strconcat (BST_PATH_DOCS, "/faq.markup", NULL);
-      help_title = g_strdup (help_file);
-      goto HELP_DIALOG;
+      docs_url = "html/faq.html";
+      docs_title = "BEAST FAQ";
+      goto BROWSE_LOCAL_URL;
     case ACTION_HELP_QUICK_START:
-      help_file = g_strconcat (BST_PATH_DOCS, "/quickstart.markup", NULL);
-      help_title = g_strdup (help_file);
-      goto HELP_DIALOG;
+      docs_url = "html/quickstart.html";
+      docs_title = "BEAST Quick Start Guide";
+      goto BROWSE_LOCAL_URL;
     case ACTION_HELP_RELEASE_NOTES:
-      help_file = g_strconcat (BST_PATH_DOCS, "/release-notes.markup", NULL);
-      help_title = g_strdup_printf (_("BEAST-%s Release Notes"), BST_VERSION);
-      goto HELP_DIALOG;
+      docs_url = "html/release-notes.html";
+      docs_title = "BEAST Release Notes";
+      goto BROWSE_LOCAL_URL;
     case ACTION_HELP_DSP_ENGINE:
-      help_file = g_strconcat (BST_PATH_DOCS, "/engine-mplan.markup", NULL);
-      help_title = g_strdup (help_file);
-      goto HELP_DIALOG;
+      docs_url = "html/engine-mplan.html";
+      docs_title = "BEAST DSP Engine";
+      goto BROWSE_LOCAL_URL;
     case ACTION_HELP_PLUGIN_DEVEL:
-      help_file = g_strconcat (BST_PATH_DOCS, "/plugin-devel.markup", NULL);
-      help_title = g_strdup (help_file);
-      goto HELP_DIALOG;
+      docs_url = "html/plugin-devel.html";
+      docs_title = "BEAST Plugin Development";
+      goto BROWSE_LOCAL_URL;
     case ACTION_HELP_DEVELOPMENT:
-      help_file = g_strconcat (BST_PATH_DOCS, "/beast-index.markup#development", NULL);
-      help_title = g_strdup (help_file);
-      goto HELP_DIALOG;
-    HELP_DIALOG:
-      if (!bst_help_dialogs[action - ACTION_HELP_FIRST])
+      docs_url = "html/beast-index.html#development";
+      docs_title = "BEAST Development Index";
+      goto BROWSE_LOCAL_URL;
+    BROWSE_LOCAL_URL:
+      if (docs_url)
         {
-          GtkWidget *sctext = gxk_scroll_text_create (GXK_SCROLL_TEXT_NAVIGATABLE, NULL);
-          gchar *index = g_strconcat ("file://", BST_PATH_DOCS, "/beast-index.markup", NULL);
-          gxk_scroll_text_set_index (sctext, index);
-          g_free (index);
-          gxk_scroll_text_enter (sctext, help_file);
-          bst_help_dialogs[action - ACTION_HELP_FIRST] = gxk_dialog_new (&bst_help_dialogs[action - ACTION_HELP_FIRST],
-                                                                         NULL,
-                                                                         GXK_DIALOG_HIDE_ON_DELETE | GXK_DIALOG_DELETE_BUTTON,
-                                                                         help_title, sctext);
-          gxk_dialog_set_sizes (GXK_DIALOG (bst_help_dialogs[action - ACTION_HELP_FIRST]), 500, 400, 560, 640);
+          gchar *local_url = g_strconcat ("file://", BST_PATH_DOCS, "/", docs_url, NULL);
+          sfi_url_show_with_cookie (local_url, docs_title, self->cookie);
+          g_free (local_url);
         }
-      g_free (help_file);
-      g_free (help_title);
-      gxk_scroll_text_rewind (gxk_dialog_get_child (GXK_DIALOG (bst_help_dialogs[action - ACTION_HELP_FIRST])));
-      gxk_widget_showraise (bst_help_dialogs[action - ACTION_HELP_FIRST]);
       break;
     case ACTION_HELP_ABOUT:
       beast_show_about_box ();
       break;
     case ACTION_URL_HELP_DESK:
-      gxk_show_url ("http://beast.gtk.org/wiki:HelpDesk");
+      sfi_url_show ("http://beast.gtk.org/wiki:HelpDesk");
       break;
     case ACTION_URL_BEAST_SITE:
-      gxk_show_url ("http://beast.gtk.org/");
+      sfi_url_show ("http://beast.gtk.org/");
+      break;
+    case ACTION_URL_REPORT_BUG:
+      sfi_url_show ("http://bugzilla.gnome.org/simple-bug-guide.cgi?product=beast");
       break;
     case ACTION_URL_ONLINE_SYNTHESIZERS:
-      gxk_show_url ("http://beast.gtk.org/browse-bse-files.html");
+      sfi_url_show ("http://beast.gtk.org/sound-browser");
       break;
     case ACTION_URL_ONLINE_DEMOS:
-      gxk_show_url ("http://beast.gtk.org/browse-bse-files.html");
+      sfi_url_show ("http://beast.gtk.org/sound-browser");
       break;
-    case ACTION_DEMO_DIALOG_FATAL:
     case ACTION_DEMO_DIALOG_ERROR:
     case ACTION_DEMO_DIALOG_WARNING:
     case ACTION_DEMO_DIALOG_SCRIPT:
@@ -1129,7 +1122,6 @@ app_action_exec (gpointer data,
       switch (action)
         {
         default: /* silence compiler */
-        case ACTION_DEMO_DIALOG_FATAL:   demo_type = BST_MSG_FATAL;   break;
         case ACTION_DEMO_DIALOG_ERROR:   demo_type = BST_MSG_ERROR;   break;
         case ACTION_DEMO_DIALOG_WARNING: demo_type = BST_MSG_WARNING; break;
         case ACTION_DEMO_DIALOG_SCRIPT:  demo_type = BST_MSG_SCRIPT;  break;
@@ -1138,13 +1130,13 @@ app_action_exec (gpointer data,
         case ACTION_DEMO_DIALOG_DEBUG:   demo_type = BST_MSG_DEBUG;   break;
         }
       bst_msg_dialog (demo_type,
-                      SFI_MSG_TEXT0 ("Demonstration Dialog"),
-                      SFI_MSG_TEXT1 ("This is a demonstrative dialog"),
-                      SFI_MSG_TEXT2 ("To help with dialog layout, and to test message display, dialogs may be "
+                      BST_MSG_TEXT0 ("Demonstration Dialog"),
+                      BST_MSG_TEXT1 ("This is a demonstration dialog"),
+                      BST_MSG_TEXT2 ("To help with dialog layout, and to test message display, dialogs may be "
                                      "fired up for pure demonstration purposes. This is such a dialog, so if you "
                                      "are currently looking at a prominent warning or error message, there's no "
                                      "real merit to it."),
-                      SFI_MSG_TEXT3 ("Demo-Dialog-Type: %s", sfi_msg_type_label (demo_type)));
+                      BST_MSG_TEXT3 ("Demo-Dialog-Type: %s", sfi_msg_type_label (demo_type)));
       break;
     default:
       g_assert_not_reached ();
@@ -1229,9 +1221,9 @@ app_action_check (gpointer data,
     case ACTION_HELP_ABOUT:
     case ACTION_URL_HELP_DESK:
     case ACTION_URL_BEAST_SITE:
+    case ACTION_URL_REPORT_BUG:
     case ACTION_URL_ONLINE_SYNTHESIZERS:
     case ACTION_URL_ONLINE_DEMOS:
-    case ACTION_DEMO_DIALOG_FATAL:
     case ACTION_DEMO_DIALOG_ERROR:
     case ACTION_DEMO_DIALOG_WARNING:
     case ACTION_DEMO_DIALOG_SCRIPT:
