@@ -25,7 +25,8 @@
 static void     bus_editor_action_exec           (gpointer                data,
                                                   gulong                  action);
 static gboolean bus_editor_action_check          (gpointer                data,
-                                                  gulong                  action);
+                                                  gulong                  action,
+                                                  guint64                 action_stamp);
 
 
 /* --- bus actions --- */
@@ -107,11 +108,8 @@ bus_probes_notify (SfiProxy     bus,
     bst_db_beam_set_value (self->lbeam, lprobe->energie);
   if (self->rbeam && rprobe && rprobe->probe_features->probe_energie)
     bst_db_beam_set_value (self->rbeam, rprobe->energie);
-  if (BST_GCONFIG (enable_meters))
-    {
-      bse_source_queue_probe_request (self->item, 0, 1, 1, 0, 0);
-      bse_source_queue_probe_request (self->item, 1, 1, 1, 0, 0);
-    }
+  bst_source_queue_probe_request (self->item, 0, BST_SOURCE_PROBE_ENERGIE, 20.0);
+  bst_source_queue_probe_request (self->item, 1, BST_SOURCE_PROBE_ENERGIE, 20.0);
   bse_probe_seq_free (pseq);
 }
 
@@ -204,11 +202,8 @@ bst_bus_editor_set_bus (BstBusEditor *self,
       bse_proxy_connect (self->item,
                          "signal::probes", bus_probes_notify, self,
                          NULL);
-      if (BST_GCONFIG (enable_meters))
-        {
-          bse_source_queue_probe_request (self->item, 0, 1, 1, 0, 0);
-          bse_source_queue_probe_request (self->item, 1, 1, 1, 0, 0);
-        }
+      bst_source_queue_probe_request (self->item, 0, BST_SOURCE_PROBE_ENERGIE, 20.0);
+      bst_source_queue_probe_request (self->item, 1, BST_SOURCE_PROBE_ENERGIE, 20.0);
     }
 }
 
@@ -231,7 +226,8 @@ bus_editor_action_exec (gpointer data,
 
 static gboolean
 bus_editor_action_check (gpointer data,
-                        gulong   action)
+                         gulong   action,
+                         guint64  action_stamp)
 {
   // BstBusEditor *self = BST_BUS_EDITOR (data);
   switch (action)
