@@ -19,7 +19,7 @@
 #ifndef __BST_CLUE_HUNTER_H__
 #define __BST_CLUE_HUNTER_H__
 
-#include	<gtk/gtk.h>
+#include <gxk/gxk.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -48,12 +48,12 @@ struct	_BstClueHunter
   guint		 popped_up : 1;
   guint		 completion_tag : 1;
   guint		 pattern_matching : 1;
-  guint		 align_width : 1;
   guint		 keep_history : 1;
   guint		 clist_column : 16;
 
   gchar		*cstring;
 
+  GtkWidget     *align_widget;
   GtkWidget	*scw;
   GtkCList	*clist;
   GtkEntry	*entry;
@@ -74,6 +74,7 @@ struct	_BstClueHunterClass
 /* --- prototypes --- */
 GtkType	   bst_clue_hunter_get_type	        (void);
 void	   bst_clue_hunter_popup	        (BstClueHunter	*clue_hunter);
+void	   bst_clue_hunter_popup_if_editable    (BstClueHunter	*clue_hunter);
 void	   bst_clue_hunter_set_clist	        (BstClueHunter	*clue_hunter,
 						 GtkCList	*clist,
 						 guint16	 column);
@@ -89,8 +90,9 @@ void	   bst_clue_hunter_select_on	        (BstClueHunter	*clue_hunter,
 						 const gchar	*string);
 void	   bst_clue_hunter_poll_refresh	        (BstClueHunter	*clue_hunter);
 gchar*	   bst_clue_hunter_try_complete	        (BstClueHunter	*clue_hunter);
-GtkWidget* bst_clue_hunter_create_arrow		(BstClueHunter	*clue_hunter);
-BstClueHunter* bst_clue_hunter_from_entry	(GtkEntry	*entry);
+GtkWidget* bst_clue_hunter_create_arrow		(BstClueHunter	*clue_hunter,
+                                                 gboolean        require_editable);
+gpointer   bst_clue_hunter_from_entry		(gpointer	 entry);
 
 
 
