@@ -43,24 +43,25 @@ typedef enum {
 typedef struct _BstKeyBinding BstKeyBinding;
 
 /* choose IDs that are unlikely to clash with category IDs */
-#define BST_GENERIC_ROLL_TOOL_FIRST	(G_MAXINT - 100000)
+#define BST_COMMON_ROLL_TOOL_FIRST	(G_MAXINT - 100000)
 typedef enum /*< skip >*/
 {
-  BST_GENERIC_ROLL_TOOL_NONE,
-  BST_GENERIC_ROLL_TOOL_INSERT            = BST_GENERIC_ROLL_TOOL_FIRST,
-  BST_GENERIC_ROLL_TOOL_RESIZE,
-  BST_GENERIC_ROLL_TOOL_LINK,
-  BST_GENERIC_ROLL_TOOL_RENAME,
-  BST_GENERIC_ROLL_TOOL_ALIGN,
-  BST_GENERIC_ROLL_TOOL_MOVE,
-  BST_GENERIC_ROLL_TOOL_DELETE,
-  BST_GENERIC_ROLL_TOOL_SELECT,
-  BST_GENERIC_ROLL_TOOL_VSELECT,
-  BST_GENERIC_ROLL_TOOL_EDITOR,
-  BST_GENERIC_ROLL_TOOL_MOVE_TICK_POINTER,
-  BST_GENERIC_ROLL_TOOL_MOVE_TICK_LEFT,
-  BST_GENERIC_ROLL_TOOL_MOVE_TICK_RIGHT,
-} BstGenericRollTool;
+  BST_COMMON_ROLL_TOOL_NONE,
+  BST_COMMON_ROLL_TOOL_INSERT            = BST_COMMON_ROLL_TOOL_FIRST,
+  BST_COMMON_ROLL_TOOL_RESIZE,
+  BST_COMMON_ROLL_TOOL_LINK,
+  BST_COMMON_ROLL_TOOL_RENAME,
+  BST_COMMON_ROLL_TOOL_ALIGN,
+  BST_COMMON_ROLL_TOOL_MOVE,
+  BST_COMMON_ROLL_TOOL_DELETE,
+  BST_COMMON_ROLL_TOOL_SELECT,
+  BST_COMMON_ROLL_TOOL_VSELECT,
+  BST_COMMON_ROLL_TOOL_EDITOR,
+  BST_COMMON_ROLL_TOOL_MOVE_TICK_POINTER,
+  BST_COMMON_ROLL_TOOL_MOVE_TICK_LEFT,
+  BST_COMMON_ROLL_TOOL_MOVE_TICK_RIGHT,
+  BST_COMMON_ROLL_TOOL_LAST
+} BstCommonRollTool;
 
 
 /* --- constants & defines --- */
