@@ -16,6 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 #include "bstutils.h"
+#include "bstcxxutils.h"
 #include "bse/bse.h"
 #include "bstapp.h"
 #include "bstsplash.h"
@@ -38,8 +39,7 @@
 
 /* --- prototypes --- */
 static void			bst_early_parse_args	(gint        *argc_p,
-							 gchar     ***argv_p,
-							 SfiRec	     *bseconfig);
+							 gchar     ***argv_p);
 static void			bst_print_blurb		(void);
 static void			bst_exit_print_version	(void);
 
@@ -83,10 +83,13 @@ main (int   argc,
       char *argv[])
 {
   GdkPixbufAnimation *anim;
-  BstApp *app = NULL;
-  SfiRec *bseconfig;
   gchar *string;
   GSource *source;
+  char debugbool[2] = "0";
+  SfiInitValue config[] = {
+    { "debug-extensions", debugbool },
+    { NULL },
+  };
   guint i;
 
   /* initialize i18n */
@@ -95,27 +98,30 @@ main (int   argc,
   textdomain (BST_GETTEXT_DOMAIN);
   setlocale (LC_ALL, "");
 
+  /* initialize random numbers */
+  struct timeval tv;
+  gettimeofday (&tv, NULL);
+  srand48 (tv.tv_usec + (tv.tv_sec << 16));
+  srand (tv.tv_usec + (tv.tv_sec << 16));
+
   /* initialize GLib guts */
   // toyprof_init_glib_memtable ("/tmp/beast-leak.debug", 10 /* SIGUSR1 */);
   g_thread_init (NULL);
   g_type_init ();
 
-  /* initialize Sfi guts */
-  sfi_init ();
+  /* initialize Birnet/Sfi */
+  sfi_init (&argc, &argv, _("BEAST"), NULL);  /* application name is user visible */       
   sfi_msg_allow ("misc");
   /* ensure SFI can wake us up */
   sfi_thread_set_name ("Beast GUI");
-  sfi_thread_set_wakeup ((SfiThreadWakeup) g_main_context_wakeup,
+  sfi_thread_set_wakeup ((BirnetThreadWakeup) g_main_context_wakeup,
 			 g_main_context_default (), NULL);
 
-  /* pre-parse BEAST args */
-  bseconfig = sfi_rec_new ();
-
   /* initialize Gtk+ and go into threading mode */
-  bst_early_parse_args (&argc, &argv, bseconfig);
+  bst_early_parse_args (&argc, &argv);
+  if (bst_debug_extensions)
+    debugbool[0] = '1';
   gtk_init (&argc, &argv);
-  g_set_prgname ("beast");	        /* overriding Gdk's program name */
-  g_set_application_name (_("BEAST"));  /* User visible name */       
   GDK_THREADS_ENTER ();
 
   /* initialize Gtk+ Extension Kit */
@@ -163,8 +169,7 @@ main (int   argc,
 
   /* start BSE core and connect */
   bst_splash_update_item (beast_splash, _("BSE Core"));
-  bse_init_async (&argc, &argv, bseconfig);
-  sfi_rec_unref (bseconfig);
+  bse_init_async (&argc, &argv, "BEAST", config);
   sfi_glue_context_push (bse_init_glue_context ("BEAST"));
   source = g_source_simple (GDK_PRIORITY_EVENTS, // G_PRIORITY_HIGH - 100,
 			    (GSourcePending) sfi_glue_context_pending,
@@ -253,18 +258,24 @@ main (int   argc,
   _bst_init_radgets ();
 
   /* install message dialog handler */
-  sfi_msg_set_thread_handler (bst_message_log_handler);
+  bst_message_handler_install();
 
   /* open files given on command line */
   if (argc > 1)
     bst_splash_update_entity (beast_splash, _("Loading..."));
+  BstApp *app = NULL;
+  gboolean merge_with_last = FALSE;
   for (i = 1; i < argc; i++)
     {
-      SfiProxy project, wrepo;
-      BseErrorType error;
-
       bst_splash_update ();
 
+      /* parse non-file args */
+      if (strcmp (argv[i], "--merge") == 0)
+        {
+          merge_with_last = TRUE;
+          continue;
+        }
+
       /* load waves into the last project */
       if (bse_server_can_load (BSE_SERVER, argv[i]))
 	{
@@ -272,16 +283,16 @@ main (int   argc,
 	    {
 	      SfiProxy wrepo = bse_project_get_wave_repo (app->project);
 	      gxk_status_printf (GXK_STATUS_WAIT, NULL, _("Loading \"%s\""), argv[i]);
-	      error = bse_wave_repo_load_file (wrepo, argv[i]);
+	      BseErrorType error = bse_wave_repo_load_file (wrepo, argv[i]);
               bst_status_eprintf (error, _("Loading \"%s\""), argv[i]);
               if (error)
                 sfi_error (_("Failed to load wave file \"%s\": %s"), argv[i], bse_error_blurb (error));
 	    }
           else
 	    {
-	      project = bse_server_use_new_project (BSE_SERVER, "Untitled.bse");
-	      wrepo = bse_project_get_wave_repo (project);
-	      error = bse_wave_repo_load_file (wrepo, argv[i]);
+	      SfiProxy project = bse_server_use_new_project (BSE_SERVER, "Untitled.bse");
+	      SfiProxy wrepo = bse_project_get_wave_repo (project);
+	      BseErrorType error = bse_wave_repo_load_file (wrepo, argv[i]);
 	      if (!error)
 		{
 		  app = bst_app_new (project);
@@ -298,20 +309,28 @@ main (int   argc,
           continue;
 	}
 
-      /* load projects */
-      project = bse_server_use_new_project (BSE_SERVER, argv[i]);
-      error = bst_project_restore_from_file (project, argv[i], TRUE);
-      
-      if (!error)
-	{
-	  app = bst_app_new (project);
-	  gxk_idle_show_widget (GTK_WIDGET (app));
-	  gtk_widget_hide (beast_splash);
-	}
-      bse_item_unuse (project);
-      
-      if (error)
-        sfi_error (_("Failed to load project \"%s\": %s"), argv[i], bse_error_blurb (error));
+      /* load/merge projects */
+      if (!app || !merge_with_last)
+        {
+          SfiProxy project = bse_server_use_new_project (BSE_SERVER, argv[i]);
+          BseErrorType error = bst_project_restore_from_file (project, argv[i], TRUE, TRUE);
+          if (!error || error == BSE_ERROR_FILE_NOT_FOUND)
+            {
+              error = 0;
+              app = bst_app_new (project);
+              gxk_idle_show_widget (GTK_WIDGET (app));
+              gtk_widget_hide (beast_splash);
+            }
+          bse_item_unuse (project);
+          if (error)
+            sfi_error (_("Failed to load project \"%s\": %s"), argv[i], bse_error_blurb (error));
+        }
+      else
+        {
+          BseErrorType error = bst_project_restore_from_file (app->project, argv[i], TRUE, FALSE);
+          if (error)
+            sfi_error (_("Failed to merge project \"%s\": %s"), argv[i], bse_error_blurb (error));
+        }
     }
 
   /* open default app window
@@ -333,11 +352,44 @@ main (int   argc,
   gboolean update_rc_files = FALSE;
   if (!BST_RC_VERSION || strcmp (BST_RC_VERSION, BST_VERSION))
     {
+      const char *release_notes_title =
+        "BEAST/BSE Release Notes";
+      const char *release_notes_contents =
+        "<tag-span-markup>"
+        "<tagdef name=\"title\" weight=\"bold\" scale=\"1.5\"/>"
+        "<tagdef name=\"hyperlink\" underline=\"single\" foreground=\"#0000ff\"/>"
+        "<tagdef name=\"mono\" family=\"monospace\"/>"
+        "<span tag=\"title\">BEAST/BSE " BST_VERSION " Release Notes</span>"
+        "<newline/><newline/>"
+        "The 0.7 development series of Beast focusses on improving usability and ease of music production. "
+        "<newline/><newline/>"
+        "Feedback is very much appreciated, please take the opportunity and provide your comments "
+        "and questions in online forums like the Beast "
+        "<span tag=\"hyperlink\"><xlink ref=\"http://beast.gtk.org/wiki:HelpDesk\">Help Desk</xlink></span>, Beast "
+        "<span tag=\"hyperlink\"><xlink ref=\"http://bugzilla.gnome.org/buglist.cgi?query=product:beast\">Bugzilla</xlink></span> "
+        "or the "
+        "<span tag=\"hyperlink\"><xlink ref=\"http://beast.gtk.org/contact\">mailing list</xlink></span>, "
+        "all of which can be reached through the links provided by the Help/ menu."
+        "<newline/><newline/>"
+        "The Beast website also provides much more information like detailed "
+        "<span tag=\"hyperlink\"><xlink ref=\"http://beast.gtk.org/news-file\">release NEWS</xlink></span>, "
+        "synthesis hints, documentation and a "
+        "<span tag=\"hyperlink\"><xlink ref=\"http://beast.gtk.org/sound-browser\">sound archive</xlink></span>. "
+        "<newline/>"
+        "So either activate 'Help/Beast Website...' or go to:"
+        "<newline/>"
+        "<span tag=\"mono\">        </span><span tag=\"hyperlink\"><xlink ref=\"http://beast.gtk.org\">http://beast.gtk.org</xlink></span>"
+        "</tag-span-markup>";
+      GtkWidget *sctext = gxk_scroll_text_create (GXK_SCROLL_TEXT_WRAP | GXK_SCROLL_TEXT_SANS | GXK_SCROLL_TEXT_CENTER, NULL);
+      gxk_scroll_text_set_tsm (sctext, release_notes_contents);
+      GtkWidget *rndialog = gxk_dialog_new (NULL, NULL, GXK_DIALOG_DELETE_BUTTON, release_notes_title, sctext);
+      gxk_dialog_set_sizes (GXK_DIALOG (rndialog), 320, 200, 540, 420);
+      gxk_scroll_text_rewind (sctext);
+      gxk_idle_show_widget (rndialog);
       update_rc_files = TRUE;
-      bst_app_show_release_notes (app);
       bst_gconfig_set_rc_version (BST_VERSION);
     }
-
+  
   /* release splash grab */
   gtk_widget_hide (beast_splash);
   bst_splash_release_grab (beast_splash);
@@ -351,7 +403,7 @@ main (int   argc,
     }
   
   /* take down GUI */
-  sfi_msg_set_thread_handler (NULL);
+  bst_message_handler_uninstall();
   bst_message_dialogs_popdown ();
   
   /* perform necessary cleanup cycles */
@@ -386,6 +438,7 @@ main (int   argc,
       sfi_glue_gc_run ();
       GDK_THREADS_LEAVE ();
     }
+  birnet_cleanup_force_handlers();
 
   bse_object_debug_leaks ();
   
@@ -394,8 +447,7 @@ main (int   argc,
 
 static void
 bst_early_parse_args (int    *argc_p,
-		      char ***argv_p,
-		      SfiRec *bseconfig)
+		      char ***argv_p)
 {
   guint argc = *argc_p;
   gchar **argv = *argv_p;
@@ -457,7 +509,6 @@ bst_early_parse_args (int    *argc_p,
 	      bst_debug_extensions = TRUE;
 	      g_message ("enabling possibly harmful debugging extensions due to '-:d'");
 	    }
-	  sfi_rec_set_bool (bseconfig, "debug-extensions", bst_debug_extensions);
 	  argv[i] = NULL;
 	}
       else if (strcmp ("--devel", argv[i]) == 0)
@@ -471,7 +522,7 @@ bst_early_parse_args (int    *argc_p,
 	  guint j;
 	  g_print ("BEAST debug keys: all");
 	  for (j = 0; mids[j].ident; j++)
-            if (mids[j].type >= SFI_MSG_DEBUG && mids[j].label)
+            if (mids[j].type >= SFI_MSG_DEBUG && mids[j].label && mids[j].label[0])
               g_print (", %s (%s)", mids[j].ident, mids[j].label);
             else if (mids[j].type >= SFI_MSG_DEBUG)
               g_print (", %s", mids[j].ident);
@@ -494,9 +545,9 @@ bst_early_parse_args (int    *argc_p,
 	  argv[i] = NULL;
 	}
       else if (strcmp ("--no-debug", argv[i]) == 0 ||
-	       strncmp ("--no-debug=", argv[i], 8) == 0)
+	       strncmp ("--no-debug=", argv[i], 11) == 0)
 	{
-	  gchar *equal = argv[i] + 7;
+	  gchar *equal = argv[i] + 10;
 	  
 	  if (*equal == '=')
             sfi_msg_deny (equal + 1);
@@ -640,7 +691,7 @@ bst_early_parse_args (int    *argc_p,
 
   if (initialize_bse_and_exit)
     {
-      bse_init_async (argc_p, argv_p, bseconfig);
+      bse_init_async (argc_p, argv_p, "BEAST", NULL);
       exit (0);
     }
 }
@@ -651,14 +702,16 @@ bst_exit_print_version (void)
   const gchar *c;
   gchar *freeme = NULL;
   /* hack: start BSE, so we can query it for paths, works since we immediately exit() afterwards */
-  bse_init_async (NULL, NULL, NULL);
+  bse_init_async (NULL, NULL, "BEAST", NULL);
   sfi_glue_context_push (bse_init_glue_context ("BEAST"));
   g_print ("BEAST version %s (%s)\n", BST_VERSION, BST_VERSION_HINT);
   g_print ("Libraries: ");
   g_print ("GLib %u.%u.%u", glib_major_version, glib_minor_version, glib_micro_version);
   g_print (", SFI %u.%u.%u", bse_major_version, bse_minor_version, bse_micro_version);
   g_print (", BSE %u.%u.%u", bse_major_version, bse_minor_version, bse_micro_version);
-  g_print (", Ogg/Vorbis");
+  c = bse_server_get_vorbis_version (BSE_SERVER);
+  if (c)
+    g_print (", %s", c);
   c = bse_server_get_mp3_version (BSE_SERVER);
   if (c)
     g_print (", %s", c);
@@ -668,7 +721,12 @@ bst_exit_print_version (void)
 #endif
   g_print (", GXK %s", BST_VERSION);
   g_print ("\n");
-  g_print ("Compiled for: %s\n", BST_ARCH_NAME);
+  g_print ("Compiled for %s %s SSE plugins.\n", BST_ARCH_NAME, BSE_WITH_SSE_FLAGS ? "with" : "without");
+  g_print ("Intrinsic code selected according to runtime CPU detection:\n");
+  const SfiCPUInfo cpu_info = sfi_cpu_info();
+  gchar *cpu_blurb = sfi_cpu_info_string (&cpu_info);
+  g_print ("%s", cpu_blurb);
+  g_free (cpu_blurb);
   g_print ("\n");
   g_print ("Prefix:          %s\n", BST_PATH_PREFIX);
   g_print ("Doc Path:        %s\n", BST_PATH_DOCS);
@@ -697,39 +755,42 @@ static void
 bst_print_blurb (void)
 {
   g_print ("Usage: beast [options] [files...]\n");
+  /*        12345678901234567890123456789012345678901234567890123456789012345678901234567890 */
 #ifdef BST_WITH_XKB
   g_print ("  --force-xkb             force XKB keytable queries\n");
 #endif
-  g_print ("  --skinrc[=FILENAME]     skin resource file name\n");
-  g_print ("  --print-dir[=RESOURCE]  print the directory for a specific resource\n");
-  g_print ("  --devel                 enrich the GUI with hints useful for developers,\n");
+  g_print ("  --skinrc[=FILENAME]     Skin resource file name\n");
+  g_print ("  --print-dir[=RESOURCE]  Print the directory for a specific resource\n");
+  g_print ("  --merge                 Merge the following files into the previous project\n");
+  g_print ("  --devel                 Enrich the GUI with hints useful for developers,\n");
   g_print ("                          enable unstable plugins and experimental code\n");
-  g_print ("  -h, --help              show this help message\n");
-  g_print ("  -v, --version           print version and file paths\n");
-  g_print ("  -n NICELEVEL            run with priority NICELEVEL (for suid wrapper beast)\n");
-  g_print ("  -N                      disable renicing\n");
+  g_print ("  -h, --help              Show this help message\n");
+  g_print ("  -v, --version           Print version and file paths\n");
+  g_print ("  -n NICELEVEL            Run with priority NICELEVEL (for suid wrapper beast)\n");
+  g_print ("  -N                      Disable renicing\n");
   g_print ("  --display=DISPLAY       X server for the GUI; see X(1)\n");
-  g_print ("  --bse-latency=USECONDS  specify synthesis latency in milliseconds\n");
-  g_print ("  --bse-mixing-freq=FREQ  specify synthesis mixing frequency in Hz \n");
-  g_print ("  --bse-control-freq=FREQ specify control frequency in Hz\n");
+  g_print ("  --bse-latency=USECONDS  Specify synthesis latency in milliseconds\n");
+  g_print ("  --bse-mixing-freq=FREQ  Specify synthesis mixing frequency in Hz \n");
+  g_print ("  --bse-control-freq=FREQ Specify control frequency in Hz\n");
+  g_print ("  --bse-force-fpu         Disable loading of SSE or similarly optimized plugins\n");
   g_print ("  --bse-pcm-driver DRIVERCONF\n");
-  g_print ("  -p DRIVERCONF           try to use the PCM driver DRIVERCONF, multiple\n");
+  g_print ("  -p DRIVERCONF           Try to use the PCM driver DRIVERCONF, multiple\n");
   g_print ("                          options may be supplied to try a variety of\n");
-  g_print ("                          drivers, unless -p auto is given, only the\n");
+  g_print ("                          drivers. Uunless -p auto is given, only the\n");
   g_print ("                          drivers listed by -p options are used; each\n");
-  g_print ("                          DRIVERCONF consists of a driver name and an\n");
-  g_print ("                          optional comma seperated list of arguments,\n");
-  g_print ("                          e.g.: -p oss=/dev/dsp2,rw\n");
+  g_print ("                          DRIVERCONF consists of a driver name and may be\n");
+  g_print ("                          assigned an optional comma seperated list of\n");
+  g_print ("                          arguments, e.g.: -p oss=/dev/dsp2,rw\n");
   g_print ("  --bse-midi-driver DRIVERCONF\n");
-  g_print ("  -m DRIVERCONF           try to use the MIDI driver DRIVERCONF, multiple\n");
+  g_print ("  -m DRIVERCONF           Try to use the MIDI driver DRIVERCONF, multiple\n");
   g_print ("                          options may be specified similarly to the\n");
   g_print ("                          option handling for --bse-pcm-driver\n");
-  g_print ("  --bse-driver-list       list available PCM and MIDI drivers\n");
+  g_print ("  --bse-driver-list       List available PCM and MIDI drivers\n");
   g_print ("Development Options:\n");
-  g_print ("  --debug=KEYS            enable specific debugging messages\n");
-  g_print ("  --no-debug=KEYS         disable specific debugging messages\n");
-  g_print ("  --debug-list            list possible debug keys\n");
-  g_print ("  -:[flags]               [flags] can be any of:\n");
+  g_print ("  --debug=KEYS            Enable specific debugging messages\n");
+  g_print ("  --no-debug=KEYS         Disable specific debugging messages\n");
+  g_print ("  --debug-list            List possible debug keys\n");
+  g_print ("  -:[Flags]               [Flags] can be any combination of:\n");
   g_print ("                          f - fatal warnings\n");
   g_print ("                          N - disable script and plugin registration\n");
   g_print ("                          p - enable core plugin registration\n");
@@ -739,17 +800,14 @@ bst_print_blurb (void)
   g_print ("                          s - enable script registration\n");
   g_print ("                          S - disable script registration\n");
   g_print ("                          d - enable debugging extensions (harmfull)\n");
-  if (!BST_VERSION_STABLE)
-    {
-      g_print ("Gtk+ Options:\n");
-      g_print ("  --gtk-debug=FLAGS       Gtk+ debugging flags to enable\n");
-      g_print ("  --gtk-no-debug=FLAGS    Gtk+ debugging flags to disable\n");
-      g_print ("  --gtk-module=MODULE     load additional Gtk+ modules\n");
-      g_print ("  --gdk-debug=FLAGS       Gdk debugging flags to enable\n");
-      g_print ("  --gdk-no-debug=FLAGS    Gdk debugging flags to disable\n");
-      g_print ("  --g-fatal-warnings      make warnings fatal (abort)\n");
-      g_print ("  --sync                  do all X calls synchronously\n");
-    }
+  g_print ("Gtk+ Options:\n");
+  g_print ("  --gtk-debug=FLAGS       Gtk+ debugging flags to enable\n");
+  g_print ("  --gtk-no-debug=FLAGS    Gtk+ debugging flags to disable\n");
+  g_print ("  --gtk-module=MODULE     Load additional Gtk+ modules\n");
+  g_print ("  --gdk-debug=FLAGS       Gdk debugging flags to enable\n");
+  g_print ("  --gdk-no-debug=FLAGS    Gdk debugging flags to disable\n");
+  g_print ("  --g-fatal-warnings      Make warnings fatal (abort)\n");
+  g_print ("  --sync                  Do all X calls synchronously\n");
 }
 
 void
@@ -769,6 +827,7 @@ beast_show_about_box (void)
     /* general code and fixes */
     "Alper Ersoy",
     "Ben Collver",
+    "Hanno Behrens",
     "Nedko Arnaudov",
     "Rasmus Kaj",
     "Sam Hocevar",
@@ -788,6 +847,7 @@ beast_show_about_box (void)
     "Christian Neumair",
     "Christian Rose",
     "Christophe Merlet",
+    "Daniel Nylander",
     "Danilo Segan",
     "David Lodge",
     "Dirk Janik",
@@ -795,10 +855,13 @@ beast_show_about_box (void)
     "Dulmandakh Sukhbaatar",
     "Francisco Javier F. Serrador",
     "Gareth Owen",
+    "Gil Forcada",
+    "Hendrik Richter",
     "Hizkuntza Politikarako Sailburuordetza",
     "Iassen Pramatarov",
     // "I\xc3\261aki Larra\xc3\261aga Murgotio",
     "Ismael Andres Rubio Rojas",
+    "Jens Seidel",
     "Jorge Gonzalez",
     "Kees van den Broek",
     "Kostas Papadimas",
@@ -806,6 +869,7 @@ beast_show_about_box (void)
     "Metin Amiroff",
     "Miloslav Trmac",
     "Moritz Mekelburger",
+    "Pawan Chitrakar",
     "Petrecca Michele",
     "Raphael Higino",
     "Robert Sedak",
