@@ -26,7 +26,8 @@
 static void     part_view_action_exec           (gpointer                data,
                                                  gulong                  action);
 static gboolean part_view_action_check          (gpointer                data,
-                                                 gulong                  action);
+                                                 gulong                  action,
+                                                 guint64                 action_stamp);
 
 
 /* --- part actions --- */
@@ -124,7 +125,8 @@ part_view_action_exec (gpointer                data,
 
 static gboolean
 part_view_action_check (gpointer                data,
-                        gulong                  action)
+                        gulong                  action,
+                        guint64                 action_stamp)
 {
   BstPartView *self = BST_PART_VIEW (data);
   BstItemView *item_view = BST_ITEM_VIEW (self);
