@@ -120,7 +120,8 @@ pattern_column_note_char (BstPatternColumnNote *self,
   else if (pseq->n_pnotes > 1)
     return '*';
   /* pseq->n_pnotes == 1 */
-  ndesc = bse_server_describe_note (BSE_SERVER, pseq->pnotes[0]->note, pseq->pnotes[0]->fine_tune);
+  ndesc = bse_note_describe (BSE_MUSICAL_TUNING_12_TET, /* tuning is irrelevant if we ignore ->freq */
+                             pseq->pnotes[0]->note, pseq->pnotes[0]->fine_tune);
   switch (pos)
     {
     case 0:     return ndesc->upshift ? '#' : ' ';
@@ -446,7 +447,7 @@ pattern_column_event_draw_cell (BstPatternColumn       *column,
   BstPatternColumnEvent *self = (BstPatternColumnEvent*) column;
   GdkGC *inactive_gc = gcs[BST_PATTERN_COLUMN_GC_TEXT0];
   GdkGC *text_gc = gcs[BST_PATTERN_COLUMN_GC_TEXT1];
-  gchar placeholder;
+  gchar placeholder = 0;
   BsePartControl *pctrl = pattern_column_event_lookup (column, pview, tick, duration, NULL, &placeholder);
   gchar buffer[64] = { 0, };
   guint n = pattern_column_event_to_string (column, buffer, pctrl, placeholder, NULL);
@@ -504,7 +505,7 @@ pattern_column_event_key_event (BstPatternColumn       *column,
   guint n_digits = MIN (9, 1 + (column->lflags & BST_PATTERN_LFLAG_DIGIT_MASK));
   gboolean is_signed = (column->lflags & BST_PATTERN_LFLAG_SIGNED) != 0;
   SfiProxy proxy = pview->proxy;
-  gchar placeholder;
+  gchar placeholder = 0;
   BsePartControlSeq *cseq;
   BsePartControl *pctrl = pattern_column_event_lookup (column, pview, tick, duration, &cseq, &placeholder);
   gchar buffer[64] = { 0, };
