@@ -42,12 +42,15 @@ bst_play_back_handle_new (void)
   handle->snet = bse_project_create_csynth (handle->project, NULL);
   bse_proxy_set (handle->snet, "auto_activate", TRUE, NULL);
   handle->speaker = bse_snet_create_source (handle->snet, "BsePcmOutput");
-  handle->wosc = bse_snet_create_source (handle->snet, "BseWaveOsc");
-  bse_source_set_input_by_id (handle->speaker, 0, handle->wosc, 0);
-  bse_source_set_input_by_id (handle->speaker, 1, handle->wosc, 0);
+  handle->wosc1 = bse_snet_create_source (handle->snet, "BseWaveOsc");
+  handle->wosc2 = bse_snet_create_source (handle->snet, "BseWaveOsc");
+  bse_proxy_set (handle->wosc2, "channel", 2, NULL);
+  bse_source_set_input_by_id (handle->speaker, 0, handle->wosc1, 0);
+  bse_source_set_input_by_id (handle->speaker, 1, handle->wosc2, 0);
   handle->constant = bse_snet_create_source (handle->snet, "BseConstant");
-  bse_source_set_input_by_id (handle->wosc, 0, handle->constant, 0);
-  bse_proxy_connect (handle->wosc,
+  bse_source_set_input_by_id (handle->wosc1, 0, handle->constant, 0);
+  bse_source_set_input_by_id (handle->wosc2, 0, handle->constant, 0);
+  bse_proxy_connect (handle->wosc1,
 		     "swapped_signal::notify_pcm_position", wave_oscillator_pcm_notify, handle,
 		     NULL);
   return handle;
@@ -63,7 +66,8 @@ bst_play_back_handle_set (BstPlayBackHandle *handle,
     g_return_if_fail (BSE_IS_EDITABLE_SAMPLE (esample));
 
   bse_proxy_set (handle->constant, "frequency_1", osc_freq, NULL);
-  bse_wave_osc_set_from_editable_sample (handle->wosc, esample);
+  bse_wave_osc_set_from_editable_sample (handle->wosc1, esample);
+  bse_wave_osc_set_from_editable_sample (handle->wosc2, esample);
 }
 
 void
@@ -80,9 +84,14 @@ void
 bst_play_back_handle_seek_perc (BstPlayBackHandle *handle,
 				gfloat             perc)
 {
-  bse_wave_osc_pcm_seek_perc (handle->wosc, perc);
+  BseItemSeq *iseq = bse_item_seq_new();
+  bse_item_seq_append (iseq, handle->wosc1);
+  if (handle->wosc2)
+    bse_item_seq_append (iseq, handle->wosc2);
+  bse_wave_osc_mass_seek_perc (iseq, perc);
   if (handle->waiting_for_notify)
     handle->discard_next_notify = TRUE;
+  bse_item_seq_free (iseq);
 }
 
 void
@@ -115,7 +124,7 @@ wave_oscillator_pcm_notify (BstPlayBackHandle *handle,
 {
   gboolean discard_next_notify = handle->discard_next_notify;
 
-  g_assert (handle->wosc == wosc);
+  g_assert (handle->wosc1 == wosc);
 
   handle->waiting_for_notify = FALSE;
   handle->discard_next_notify = FALSE;
@@ -131,7 +140,7 @@ pcm_timer (gpointer data)
   GDK_THREADS_ENTER ();
   if (!handle->waiting_for_notify)
     {
-      bse_wave_osc_request_pcm_position (handle->wosc);
+      bse_wave_osc_request_pcm_position (handle->wosc1);
       handle->waiting_for_notify = TRUE;
     }
   GDK_THREADS_LEAVE ();
@@ -187,9 +196,7 @@ bst_play_back_handle_destroy (BstPlayBackHandle *handle)
 
   bst_play_back_handle_stop (handle);
 
-  bse_proxy_disconnect (handle->wosc,
-			"any_signal", wave_oscillator_pcm_notify, handle,
-			NULL);
+  bse_proxy_disconnect (handle->wosc1, "any_signal", wave_oscillator_pcm_notify, handle, NULL);
 
   if (handle->pcm_timeout)
     g_source_remove (handle->pcm_timeout);
