@@ -48,6 +48,8 @@ struct _BstPreferences
   GtkWidget            *box_piano_keys;
   GtkWidget            *box_generic_keys;
 
+  GtkWidget            *box_msg_absorb_config;
+
   SfiRec               *rec_skin;
   SfiRing              *params_skin;
 
@@ -66,6 +68,7 @@ GtkType		 bst_preferences_get_type	(void);
 void		 bst_preferences_apply		(BstPreferences *prefs);
 void		 bst_preferences_load_rc_files	(void);
 void		 bst_preferences_save		(BstPreferences *prefs);
+gboolean	 bst_preferences_saved  	(void);
 void		 bst_preferences_revert		(BstPreferences *prefs);
 void		 bst_preferences_default_revert	(BstPreferences *prefs);
 void		 bst_preferences_create_buttons (BstPreferences *prefs,
