@@ -176,7 +176,7 @@ profiler_update (void)
   GxkListWrapper *lwrapper = g_object_get_data (profiler_dialog, "list-wrapper");
   BseThreadTotals *tt = bse_collect_thread_totals ();
   sfi_thread_sleep (0); /* update accounting for self */
-  SfiThreadInfo *si = sfi_thread_info_collect (sfi_thread_self());
+  BirnetThreadInfo *si = sfi_thread_info_collect (sfi_thread_self());
   BseThreadInfo bi = { 0, };
   GSList *slist = NULL;
   guint i;
@@ -263,7 +263,7 @@ bst_profiler_window_get (void)
         NULL, NULL, 0);
       */
       gxk_tree_view_add_text_column (tview, TCOL_PRIO, "AG", 0.5, _("Nice"), _("Thread priority from -20 (high) to +19 (low)"), NULL, NULL, 0);
-      gxk_tree_view_add_text_column (tview, TCOL_PROC, "A", 0.5, _("#CPU"), _("CPU the thread is currently running on"), NULL, NULL, 0);
+      gxk_tree_view_add_text_column (tview, TCOL_PROC, "A", 0.5, _("CPU#"), _("CPU the thread is currently running on"), NULL, NULL, 0);
       g_object_set_data (profiler_dialog, "list-wrapper", lwrapper);
       profiler_update ();
     }
