@@ -66,6 +66,8 @@ filter_popup_modules (gpointer         predicate_data,
                       BseCategory     *cat)
 {
   const gchar *options = bse_type_options (cat->type);
+  if (g_option_check (options, "deprecated") && !BST_DVL_HINTS)
+    return FALSE;
   if (g_option_check (options, "unstable") && !BST_DVL_HINTS)
     return FALSE;
   return TRUE;
@@ -703,8 +705,8 @@ bst_snet_router_root_event (BstSNetRouter   *self,
                                                 BST_CHOICE_SEPERATOR,
                                                 BST_CHOICE (2, _("Properties"), PROPERTIES),
                                                 BST_CHOICE (6, _("Reset Properties"), PROPERTIES_RESET),
-                                                BST_CHOICE_S (3, _("Delete Inputs"), NO_ILINK, has_inputs),
-                                                BST_CHOICE_S (4, _("Delete Outputs"), NO_OLINK, bse_source_has_outputs (csource->source)),
+                                                BST_CHOICE_S (3, _("Disconnect Inputs"), NO_ILINK, has_inputs),
+                                                BST_CHOICE_S (4, _("Disconnect Outputs"), NO_OLINK, bse_source_has_outputs (csource->source)),
                                                 BST_CHOICE_SEPERATOR,
                                                 BST_CHOICE (5, _("Show Info"), INFO),
                                                 BST_CHOICE_SUBMENU (_("Output Signal Monitor"), choice, SIGNAL),
