@@ -173,7 +173,7 @@ track_roll_get_layout (GxkScrollCanvas        *scc,
   BstTrackRoll *self = BST_TRACK_ROLL (scc);
   track_roll_update_layout (self, FALSE);
   layout->top_panel_height = MAX (1, self->area_offset - 2 * YTHICKNESS (self));
-  layout->left_panel_width = 32 + 4 * XTHICKNESS (self);
+  layout->left_panel_width = 40 + 4 * XTHICKNESS (self);
   layout->right_panel_width = 0;
   layout->bottom_panel_height = 0;
   layout->canvas_width = 1 + 2 * XTHICKNESS (self) + 1;
@@ -457,7 +457,7 @@ scope_set_track (GtkWidget *scope,
   g_object_set_long (scope, "BstTrackRoll-Track", track);
   if (BST_SNIFFER_SCOPE (scope))
     bst_sniffer_scope_set_sniffer (BST_SNIFFER_SCOPE (scope),
-                                   bse_track_create_sniffer (track));
+                                   bse_track_get_output_source (track));
 }
 
 static SfiProxy
@@ -524,6 +524,8 @@ track_roll_idle_update_scopes (gpointer data)
   
   /* allocate scopes 'n stuff */
   gxk_scroll_canvas_reallocate (GXK_SCROLL_CANVAS (self));
+  /* work around spurious redraw problems */
+  gtk_widget_queue_draw (GTK_WIDGET (self));
 
   GDK_THREADS_LEAVE ();
   return FALSE;
@@ -714,7 +716,7 @@ bst_track_roll_draw_hpanel (GxkScrollCanvas *scc,
 	  tact4 /= (self->tpt * 4);
 	  next_pixel = tick_to_coord (self, (tact4 + 1) * (self->tpt * 4));
 
-	  g_snprintf (buffer, 64, "%u", tact4 + 1);
+	  g_snprintf (buffer, 64, "%u", tact4 * 4 + 1);
           pango_layout_set_text (PLAYOUT_HPANEL (self), buffer, -1);
           pango_layout_get_pixel_extents (PLAYOUT_HPANEL (self), NULL, &rect);
           
@@ -730,11 +732,8 @@ bst_track_roll_draw_hpanel (GxkScrollCanvas *scc,
 
 	  tact /= self->tpt;
 	  next_pixel = tick_to_coord (self, (tact + 1) * self->tpt);
-          tact = tact % 4 + 1;
-          if (tact == 1444)
-            continue;   /* would draw on top of tact4 number */
 
-	  g_snprintf (buffer, 64, ":%u", tact % 4 + 1);
+	  g_snprintf (buffer, 64, "%u", tact + 1);
           pango_layout_set_text (PLAYOUT_HPANEL (self), buffer, -1);
           pango_layout_get_pixel_extents (PLAYOUT_HPANEL (self), NULL, &rect);
           
@@ -765,9 +764,9 @@ bst_track_roll_allocate_scope (BstTrackRoll *self,
     {
       gint width, height;
       gdk_window_get_size (VPANEL (self), &width, &height);
-      allocation.x = 2 * XTHICKNESS (self) + 1;
+      allocation.x = 2 * XTHICKNESS (self);
       allocation.y = ry + YTHICKNESS (self) + 1;
-      allocation.width = width - 4 * XTHICKNESS (self) - 2;
+      allocation.width = width - 4 * XTHICKNESS (self);
       allocation.height = rheight - 2 * YTHICKNESS (self) - 2;
     }
   gtk_widget_size_allocate (child, &allocation);
