@@ -1,5 +1,5 @@
 /* BEAST - Bedevilled Audio System
- * Copyright (C) 1998-2003 Tim Janik
+ * Copyright (C) 1998-2006 Tim Janik
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -186,6 +186,7 @@ BstGMask*       bst_gmask_quick         (GtkWidget     *gmask_container,
 #define BST_STOCK_DOC_DEVEL             GTK_STOCK_NEW // FIXME
 #define BST_STOCK_ABOUT                 GTK_STOCK_YES // FIXME
 #define BST_STOCK_ONLINE_HELP_DESK      GTK_STOCK_HELP // FIXME
+#define BST_STOCK_ONLINE_BUGS           GTK_STOCK_HELP // FIXME
 #define BST_STOCK_ONLINE_BEAST_SITE     GTK_STOCK_HOME // FIXME
 #define BST_STOCK_ONLINE_SOUND_ARCHIVE  BST_STOCK_LOAD_LIB // FIXME
 #define BST_STOCK_ADD                   GTK_STOCK_ADD
@@ -205,6 +206,7 @@ BstGMask*       bst_gmask_quick         (GtkWidget     *gmask_container,
 #define BST_STOCK_CLOSE                 GTK_STOCK_CLOSE
 #define BST_STOCK_DEFAULT_REVERT        ("bst-stock-default-revert")
 #define BST_STOCK_DELETE                GTK_STOCK_DELETE
+#define BST_STOCK_DISMISS               ("bst-stock-dismiss")
 #define BST_STOCK_EXECUTE               GTK_STOCK_EXECUTE
 #define BST_STOCK_OK                    GTK_STOCK_OK
 #define BST_STOCK_OVERWRITE             ("bst-stock-overwrite")
