@@ -6,6 +6,10 @@
 #define GXK_TYPE_DIALOG_FLAGS	    (gxk__type_id__GxkDialogFlags)
 extern GType gxk__type_id__GxkDialogFlags;
 
+/* --- gxklogadjustment.h --- */
+#define GXK_TYPE_ADAPTER_ADJUSTMENT_CONVERT_TYPE	    (gxk__type_id__GxkAdapterAdjustmentConvertType)
+extern GType gxk__type_id__GxkAdapterAdjustmentConvertType;
+
 /* --- gxkmenubutton.h --- */
 #define GXK_TYPE_MENU_BUTTON_MODE	    (gxk__type_id__GxkMenuButtonMode)
 extern GType gxk__type_id__GxkMenuButtonMode;
