@@ -65,11 +65,12 @@ void	gxk_init	(void);
 
 
 /* --- internal --- */
-void	_gxk_init_utils		(void);
-void	_gxk_init_params	(void);
-void	_gxk_init_stock		(void);
-void	_gxk_init_actions	(void);
-void	_gxk_init_radget_types	(void);
+void	gxk_init_utils		(void);
+void	gxk_init_params	        (void);
+void	gxk_init_stock		(void);
+void	gxk_init_actions	(void);
+void	gxk_init_assortments	(void);
+void	gxk_init_radget_types	(void);
 
 
 G_END_DECLS
