@@ -1,5 +1,5 @@
 /* GXK - Gtk+ Extension Kit
- * Copyright (C) 2002-2004 Tim Janik
+ * Copyright (C) 2002-2006 Tim Janik
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -931,6 +931,15 @@ radget_parser (Domain      *domain,
 
 static GData *domains = NULL;
 
+/**
+ * @param domain_name	radget domain name
+ * @param file_name	file containing ragdet definitions
+ * @param i18n_domain	i18n domain to translate labels
+ * @param error	        GError location
+ *
+ * Parse radget definitions from @a file_name. See gxk_radget_create() and
+ * gxk_radget_complete() to make use of the definitions.
+ */
 void
 gxk_radget_parse (const gchar    *domain_name,
                   const gchar    *file_name,
@@ -956,6 +965,16 @@ gxk_radget_parse (const gchar    *domain_name,
     }
 }
 
+/**
+ * @param domain_name	radget domain name
+ * @param text	radget definition string
+ * @param text_len	length of @a text or -1
+ * @param i18n_domain	i18n domain to translate labels
+ * @param error	GError location
+ *
+ * Parse radget definitions from @a text. See gxk_radget_create() and
+ * gxk_radget_complete() to make use of the definitions.
+ */
 void
 gxk_radget_parse_text (const gchar    *domain_name,
                        const gchar    *text,
@@ -1203,7 +1222,7 @@ radget_create_from_node (Node         *node,
                          Env          *env,
                          GError      **error)
 {
-  GxkRadgetType tinfo;
+  GxkRadgetType tinfo = { 0, };
   guint i, n_pops = 0;
   /* prepare for $id/$name lookups */
   env->name = node->name;
@@ -1307,7 +1326,7 @@ radget_add_to_parent (GxkRadget    *parent,
 {
   Node *pnode = g_object_get_qdata (parent, quark_radget_node);
   Node *cnode = g_object_get_qdata (radget, quark_radget_node);
-  GxkRadgetType tinfo;
+  GxkRadgetType tinfo = { 0, };
   guint i, needs_packing, n_pops = 0;
   /* prepare for $name lookups */
   env->name = cnode->name;
@@ -1660,6 +1679,14 @@ gxk_radget_creator (GxkRadget          *radget,
   return radget_creator (radget, domain_name, name, parent, call_args, env_args);
 }
 
+/**
+ * @param domain_name	radget domain
+ * @param name	        radget definition name
+ * @param ...           NULL terminated list of variable (name, value) strings pairs
+ *
+ * Create the radget (GtkWidget or GObject) defined as @a name within @a domain,
+ * using the variable bindings as defined in the @a ... paired string list.
+ */
 GxkRadget*
 gxk_radget_create (const gchar        *domain_name,
                    const gchar        *name,
@@ -1679,6 +1706,16 @@ gxk_radget_create (const gchar        *domain_name,
   return radget;
 }
 
+/**
+ * @param radget       toplevel ragdet container
+ * @param domain_name  radget domain
+ * @param name	       radget definition name
+ * @param ...          NULL terminated list of variable (name, value) strings pairs
+ *
+ * Create the children/contents of the radget defined under @a name within @a domain
+ * as part of the container object passed in as @a radget,
+ * using the variable bindings as defined in the @a ... paired string list.
+ */
 GxkRadget*
 gxk_radget_complete (GxkRadget          *radget,
                      const gchar        *domain_name,
@@ -1698,6 +1735,13 @@ gxk_radget_complete (GxkRadget          *radget,
   return radget;
 }
 
+/**
+ * @param radget	a valid radget
+ * @return		radget domain
+ *
+ * Return the domain within which the definition was found @a radget
+ * was created from.
+ */
 const gchar*
 gxk_radget_get_domain (GxkRadget *radget)
 {
@@ -1725,6 +1769,14 @@ gxk_radget_sensitize (GxkRadget      *radget,
     }
 }
 
+/**
+ * @param radget	a valid radget
+ * @param name	radget name
+ * @return		radget named @a name or NULL
+ *
+ * Recursively find the radget named @a name within the container radget @a radget.
+ * The @a name may consist of a list of parent radget names, seperated by a dot '.'.
+ */
 gpointer
 gxk_radget_find (GxkRadget      *radget,
                  const gchar    *name)
@@ -1750,6 +1802,13 @@ gxk_radget_find (GxkRadget      *radget,
   return radget;
 }
 
+/**
+ * @param radget	a valid radget
+ * @param area	radget name
+ * @return		radget named @a name or NULL
+ *
+ * Recursively find the radget named @a name within the container radget @a radget.
+ */
 gpointer
 gxk_radget_find_area (GxkRadget      *radget,
                       const gchar    *area)
@@ -1767,6 +1826,13 @@ gxk_radget_find_area (GxkRadget      *radget,
   return radget;
 }
 
+/**
+ * @param radget	a valid radget
+ * @param area	radget name
+ * @param widget	valid GtkWidget
+ *
+ * Add the unparanted widget @a widget to @a radget within area @a area.
+ */
 void
 gxk_radget_add (GxkRadget      *radget,
                 const gchar    *area,
@@ -2139,7 +2205,7 @@ mf_blogic (GSList *args,
   while (argiter)
     {
       gchar *vbool = argiter_exp (&argiter, env);
-      gboolean b = boolean_from_string (vbool), result;
+      gboolean b = boolean_from_string (vbool);
       g_free (vbool);
       if (strcmp (name, "xor") == 0)
         result ^= b;
