@@ -99,11 +99,11 @@ main (int   argc,
   g_type_init ();
 
   /* initialize Sfi */
-  sfi_init ();
+  sfi_init (&argc, &argv, "TestGUI", NULL);
   sfi_msg_allow ("misc");
   /* ensure SFI can wake us up */
   sfi_thread_set_name ("TestGUI");
-  sfi_thread_set_wakeup ((SfiThreadWakeup) g_main_context_wakeup, g_main_context_default (), NULL);
+  sfi_thread_set_wakeup ((BirnetThreadWakeup) g_main_context_wakeup, g_main_context_default (), NULL);
 
   /* initialize Gtk+ and enter threading mode */
   gtk_init (&argc, &argv);
@@ -126,7 +126,7 @@ main (int   argc,
 
   /* start BSE core and connect */
   SfiRec *bseconfig = sfi_rec_new ();
-  bse_init_async (&argc, &argv, bseconfig);
+  bse_init_async (&argc, &argv, "TestGUI", bseconfig);
   sfi_rec_unref (bseconfig);
   sfi_glue_context_push (bse_init_glue_context ("TestGUI"));
   GSource *source = g_source_simple (G_PRIORITY_HIGH - 100,
