@@ -102,7 +102,8 @@ BSE_BUILTIN_TYPE (BseBiquadFilter)
 				   "Various types of filters are supported with "
 				   "modulatable center (Cut-Off) frequency and "
 				   "gain input signals.",
-				   &type_info);
+                                   __FILE__, __LINE__,
+                                   &type_info);
   bse_categories_register_stock_module (N_("/Filters/Biquad Types"), type, biquad_pixstream);
   return type;
 }
@@ -130,7 +131,7 @@ bse_biquad_filter_class_init (BseBiquadFilterClass *class)
 						    SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, _("Center Frequency"),
 			      PROP_FREQ,
-			      sfi_pspec_log_scale ("freq", _("Cutoff [Hz]"), NULL,
+			      sfi_pspec_log_scale ("freq", _("Cutoff [Hz]"), _("Filter cutoff frequency in Hertz"),
 						   BSE_KAMMER_FREQUENCY * 2,
 						   BSE_MIN_OSC_FREQUENCY, BSE_MAX_OSC_FREQUENCY - FREQ_DELTA,
 						   5.0,
@@ -138,8 +139,9 @@ bse_biquad_filter_class_init (BseBiquadFilterClass *class)
 						   SFI_PARAM_STANDARD ":dial"));
   bse_object_class_add_param (object_class, _("Center Frequency"),
 			      PROP_NOTE,
-			      sfi_pspec_note ("note", _("Note"), NULL,
-					      bse_note_from_freq (BSE_KAMMER_FREQUENCY * 2),
+			      sfi_pspec_note ("note", _("Note"), _("Filter cutoff frequency as note, "
+                                                                   "converted to Hertz according to the current musical tuning"),
+					      bse_note_from_freq (BSE_MUSICAL_TUNING_12_TET, BSE_KAMMER_FREQUENCY * 2),
 					      BSE_MIN_NOTE, BSE_MAX_NOTE,
 					      FALSE,
 					      SFI_PARAM_GUI));
@@ -148,6 +150,7 @@ bse_biquad_filter_class_init (BseBiquadFilterClass *class)
 			      sfi_pspec_real ("gain", _("Gain [dB]"), NULL,
 					      3, -48., +48., 3,
 					      SFI_PARAM_STANDARD ":dial"));
+#if 0
   bse_object_class_add_param (object_class, _("Emphasis"),
 			      PROP_NORM_TYPE,
 			      bse_param_spec_genum ("norm_type", _("Norm Type"),
@@ -156,6 +159,7 @@ bse_biquad_filter_class_init (BseBiquadFilterClass *class)
 						    BSE_TYPE_BIQUAD_FILTER_NORM,
 						    BSE_BIQUAD_FILTER_NORM_PASSBAND,
 						    SFI_PARAM_STANDARD));
+#endif
   bse_object_class_add_param (object_class, _("Modulation"),
 			      PROP_FM_PERC,
 			      sfi_pspec_real ("fm_perc", "Input Modulation [%]",
@@ -229,7 +233,7 @@ bse_biquad_filter_set_property (GObject	     *object,
       g_object_notify (self, "note");
       break;
     case PROP_NOTE:
-      self->freq = bse_note_to_freq (sfi_value_get_note (value));
+      self->freq = bse_note_to_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), sfi_value_get_note (value));
       bse_biquad_filter_update_modules (self);
       g_object_notify (self, "freq");
       break;
@@ -281,7 +285,7 @@ bse_biquad_filter_get_property (GObject	   *object,
       sfi_value_set_real (value, self->freq);
       break;
     case PROP_NOTE:
-      sfi_value_set_note (value, bse_note_from_freq (self->freq));
+      sfi_value_set_note (value, bse_note_from_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), self->freq));
       break;
     case PROP_FM_PERC:
       sfi_value_set_real (value, self->fm_strength * 100.0);
