@@ -16,7 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 #include "bseengineutils.h"
-
+#include "bseblockutils.hh"
 #include "gslcommon.h"
 #include "bseenginenode.h"
 #include "bseengineschedule.h"
@@ -32,7 +32,6 @@
 static inline void      engine_fetch_process_queue_trash_jobs_U (EngineTimedJob **trash_tjobs_head,
                                                                  EngineTimedJob **trash_tjobs_tail);
 
-
 /* --- UserThread --- */
 BseOStream*
 _engine_alloc_ostreams (guint n)
@@ -59,14 +58,14 @@ bse_engine_free_timed_job (EngineTimedJob *tjob)
 {
   switch (tjob->type)
     {
-      guint i;
+      BseOStream *ostreams;
     case ENGINE_JOB_PROBE_JOB:
+      ostreams = tjob->probe.ostreams;
       if (tjob->probe.probe_func)
-        tjob->probe.probe_func (tjob->probe.data, tjob->tick_stamp, tjob->probe.n_values,
-                                tjob->probe.oblocks, tjob->probe.oblock_length);
-      for (i = 0; i < tjob->probe.n_oblocks; i++)
-        if (tjob->probe.oblocks[i])
-          g_free (tjob->probe.oblocks[i]);
+        tjob->probe.probe_func (tjob->probe.data, bse_engine_block_size(), tjob->tick_stamp,
+                                tjob->probe.n_ostreams, &ostreams);
+      if (ostreams)
+        bse_engine_free_ostreams (tjob->probe.n_ostreams, ostreams);
       g_free (tjob);
       break;
     case ENGINE_JOB_FLOW_JOB:
@@ -81,6 +80,15 @@ bse_engine_free_timed_job (EngineTimedJob *tjob)
     }
 }
 
+void
+bse_engine_free_ostreams (guint         n_ostreams,
+                          BseOStream   *ostreams)
+{
+  g_assert (n_ostreams > 0);
+  /* bse_engine_block_size() may have changed since allocation */
+  g_free (ostreams);
+}
+
 static void
 bse_engine_free_node (EngineNode *node)
 {
@@ -101,7 +109,8 @@ bse_engine_free_node (EngineNode *node)
   sfi_rec_mutex_destroy (&node->rec_mutex);
   if (node->module.ostreams)
     {
-      g_free (node->module.ostreams);   /* bse_engine_block_size() may have changed since allocation */
+      /* bse_engine_block_size() may have changed since allocation */
+      bse_engine_free_ostreams (ENGINE_NODE_N_OSTREAMS (node), node->module.ostreams);
       sfi_delete_structs (EngineOutput, ENGINE_NODE_N_OSTREAMS (node), node->outputs);
     }
   if (node->module.istreams)
@@ -190,10 +199,10 @@ bse_engine_free_transaction (BseTrans *trans)
 
 
 /* --- job transactions --- */
-static SfiMutex        cqueue_trans = { 0, };
+static BirnetMutex        cqueue_trans = { 0, };
 static BseTrans       *cqueue_trans_pending_head = NULL;
 static BseTrans       *cqueue_trans_pending_tail = NULL;
-static SfiCond         cqueue_trans_cond = { 0, };
+static BirnetCond         cqueue_trans_cond = { 0, };
 static BseTrans       *cqueue_trans_trash_head = NULL;
 static BseTrans       *cqueue_trans_trash_tail = NULL;
 static BseTrans       *cqueue_trans_active_head = NULL;
@@ -354,8 +363,6 @@ _engine_pop_job (gboolean update_commit_stamp)
 
 /* --- user thread garbage collection --- */
 /**
- * bse_engine_garbage_collect
- *
  * BSE Engine user thread function. Collects processed jobs
  * and transactions from the engine and frees them. This
  * involves callback invocation of BseFreeFunc() functions,
@@ -366,7 +373,7 @@ _engine_pop_job (gboolean update_commit_stamp)
  * in the user thread.
  */
 void
-bse_engine_garbage_collect (void)
+bse_engine_user_thread_collect (void)
 {
   BseTrans *trans;
   EngineTimedJob *tjobs;
@@ -406,11 +413,11 @@ bse_engine_has_garbage (void)
 
 
 /* --- node processing queue --- */
-static SfiMutex          pqueue_mutex = { 0, };
+static BirnetMutex       pqueue_mutex = { 0, };
 static EngineSchedule   *pqueue_schedule = NULL;
 static guint             pqueue_n_nodes = 0;
 static guint             pqueue_n_cycles = 0;
-static SfiCond		 pqueue_done_cond = { 0, };
+static BirnetCond	 pqueue_done_cond = { 0, };
 static EngineTimedJob   *pqueue_trash_tjobs_head = NULL;
 static EngineTimedJob   *pqueue_trash_tjobs_tail = NULL;
 
@@ -424,6 +431,12 @@ engine_fetch_process_queue_trash_jobs_U (EngineTimedJob **trash_tjobs_head,
       *trash_tjobs_head = pqueue_trash_tjobs_head;
       *trash_tjobs_tail = pqueue_trash_tjobs_tail;
       pqueue_trash_tjobs_head = pqueue_trash_tjobs_tail = NULL;
+      /* this function may not be called while nodes are still being processed,
+       * because some (probe) jobs may reference ro-data that is still in use
+       * during processing. to ensure this, we assert that no flow processing
+       * schedule is currently set.
+       */
+      g_assert (pqueue_schedule == NULL);
       GSL_SPIN_UNLOCK (&pqueue_mutex);
     }
   else
@@ -466,6 +479,7 @@ _engine_unset_schedule (EngineSchedule *sched)
     g_warning (G_STRLOC ": schedule(%p) still busy", sched);
   sched->in_pqueue = FALSE;
   pqueue_schedule = NULL;
+  /* see engine_fetch_process_queue_trash_jobs_U() on the limitations regarding pqueue trash jobs */
   trash_tjobs_head = pqueue_trash_tjobs_head;
   trash_tjobs_tail = pqueue_trash_tjobs_tail;
   pqueue_trash_tjobs_head = pqueue_trash_tjobs_tail = NULL;
@@ -665,6 +679,15 @@ _engine_mnl_node_changed (EngineNode *node)
 
 
 /* --- const value blocks --- */
+extern const gfloat bse_engine_master_zero_block[];
+gfloat*
+bse_engine_const_zeros (guint smaller_than_BSE_STREAM_MAX_VALUES)
+{
+  /* this function is callable from any thread */
+  g_assert (smaller_than_BSE_STREAM_MAX_VALUES <= BSE_STREAM_MAX_VALUES);
+  return (gfloat*) bse_engine_master_zero_block;
+}
+
 typedef struct
 {
   guint    n_nodes;
@@ -764,7 +787,6 @@ static ConstValuesArray cvalue_array = { 0, NULL, NULL };
 gfloat*
 bse_engine_const_values (gfloat value)
 {
-  extern const gfloat bse_engine_master_zero_block[];
   gfloat **block;
   
   if (fabs (value) < BSE_SIGNAL_EPSILON)
@@ -782,11 +804,7 @@ bse_engine_const_values (gfloat value)
     {
       /* create new value block */
       gfloat *values = g_new (gfloat, bse_engine_block_size ());
-      guint i;
-      
-      for (i = 0; i < bse_engine_block_size (); i++)
-	values[i] = value;
-      
+      bse_block_fill_float (bse_engine_block_size(), values, value);
       if (block)
 	const_values_insert (&cvalue_array, block - cvalue_array.nodes, values);
       else
