@@ -39,10 +39,12 @@ glong	bse_time_range_to_ms		(BseTimeRangeType	time_range);
 
 
 /* --- async handlers --- */
+/* most important, used for immediate async execution */
+#define	BSE_PRIORITY_NOW		(-G_MAXINT / 2)
 /* very important, used for io/engine handlers */
 #define	BSE_PRIORITY_HIGH		(G_PRIORITY_HIGH - 10)
 /* still very important, used for need-to-be-async operations */
-#define	BSE_PRIORITY_NOW		(G_PRIORITY_HIGH - 5)
+#define	BSE_PRIORITY_NEXT		(G_PRIORITY_HIGH - 5)
 /* important, delivers async signals */
 #define	BSE_PRIORITY_NOTIFY		(G_PRIORITY_DEFAULT - 1)
 /* normal importantance, interfaces to glue layer */
@@ -54,6 +56,8 @@ glong	bse_time_range_to_ms		(BseTimeRangeType	time_range);
 #define BSE_PRIORITY_BACKGROUND		(G_PRIORITY_LOW + 500)
 guint	  bse_idle_now		(GSourceFunc    function,
 				 gpointer       data);
+guint	  bse_idle_next		(GSourceFunc    function,
+				 gpointer       data);
 guint	  bse_idle_notify	(GSourceFunc    function,
 				 gpointer       data);
 guint	  bse_idle_normal	(GSourceFunc    function,
@@ -75,19 +79,8 @@ guint	  bse_idle_timed	(guint64	usec_delay,
  * (SFI_KAMMER_NOTE + 12) -> 2.0
  * etc...
  */
-extern const gdouble* _bse_semitone_factor_table;
-#define	BSE_SEMITONE_FACTOR(ht)		((ht) > SFI_MAX_NOTE ? \
-				         _bse_semitone_factor_table[SFI_MAX_NOTE] : \
-				         (ht) < SFI_MIN_NOTE ? \
-				         _bse_semitone_factor_table[SFI_MIN_NOTE] : \
-				         _bse_semitone_factor_table[(ht)])
-extern const gdouble* _bse_fine_tune_factor_table;
-#define	BSE_FINE_TUNE_FACTOR(ft)	((ft) > BSE_MAX_FINE_TUNE ? \
-                                         _bse_fine_tune_factor_table[BSE_MAX_FINE_TUNE] : \
-                                         (ft) < BSE_MIN_FINE_TUNE ? \
-                                         _bse_fine_tune_factor_table[BSE_MIN_FINE_TUNE] : \
-                                         _bse_fine_tune_factor_table[(ft)])
-#define	BSE_FREQ_FROM_LINEAR_VALUE(v)	(SFI_KAMMER_FREQ_d * BSE_SEMITONE_FACTOR (BSE_NOTE_FROM_VALUE (v) - SFI_KAMMER_NOTE))
+#define	BSE_FINE_TUNE_FACTOR(ft)	(bse_cent_factor (CLAMP ((ft), BSE_MIN_FINE_TUNE, BSE_MAX_FINE_TUNE)))
+#define	BSE_TRANSPOSE_FACTOR(st)	(bse_transpose_factor (CLAMP (st, -132, +132)))	/* BSE_MAX_TRANSPOSE */
 
 
 /* --- prototypes --- */
