@@ -46,15 +46,17 @@ G_BEGIN_DECLS
 
 /* floating point type related constants */
 #define BSE_FLOAT_BIAS		 (127)
-#define	BSE_FLOAT_MAX_NORMAL	 (3.40282347e+38)	   /* 7f7fffff */
+#define	BSE_FLOAT_MAX_NORMAL	 (3.40282347e+38)	   /* 7f7fffff, 2^128 * (1 - BSE_FLOAT_EPSILON) */
 #define	BSE_FLOAT_MIN_NORMAL	 (1.17549435e-38)	   /* 00800000 */
 #define	BSE_FLOAT_MAX_SUBNORMAL	 (1.17549421e-38)	   /* 007fffff */
 #define	BSE_FLOAT_MIN_SUBNORMAL	 (1.40129846e-45)	   /* 00000001 */
+#define	BSE_FLOAT_EPSILON	 (5.9604644775390625e-08)  /* 2^-24, round-off error at 1.0 */
 #define BSE_DOUBLE_BIAS		 (1023)
-#define	BSE_DOUBLE_MAX_NORMAL	 (1.7976931348623157e+308) /* 7fefffff ffffffff */
+#define	BSE_DOUBLE_MAX_NORMAL	 (1.7976931348623157e+308) /* 7fefffff ffffffff, 2^1024 * (1 - BSE_DOUBLE_EPSILON) */
 #define	BSE_DOUBLE_MIN_NORMAL	 (2.2250738585072014e-308) /* 00100000 00000000 */
 #define	BSE_DOUBLE_MAX_SUBNORMAL (2.2250738585072009e-308) /* 000fffff ffffffff */
 #define	BSE_DOUBLE_MIN_SUBNORMAL (4.9406564584124654e-324) /* 00000000 00000001 */
+#define	BSE_DOUBLE_EPSILON	 (1.1102230246251565404236316680908203125e-16) /* 2^-53, round-off error at 1.0 */
 #define	BSE_DOUBLE_INF		 (_bse_dinf_union.d)
 #define	BSE_DOUBLE_NAN		 (_bse_dnan_union.d)
 #define	BSE_FLOAT_INF		 (_bse_finf_union.f)
@@ -106,9 +108,22 @@ G_BEGIN_DECLS
 #define BSE_DOUBLE_SIGN(d)              (BSE_DOUBLE_PARTS (d).mpn.sign)
 #endif
 
-/* get structured parts of floating point numbers */
-#define	BSE_FLOAT_PARTS(f)		(((BseFloatIEEE754) (f)))
-#define	BSE_DOUBLE_PARTS(d)		(((BseDoubleIEEE754) (d))) /* (*((BseDoubleIEEE754*) &(d))) */
+/* --- denormal float handling --- */
+static inline float	bse_float_zap_denormal	(register float  fval);	/* slow */
+static inline double	bse_double_zap_denormal	(register double dval);	/* slow */
+
+/* --- coarse but fast variants to eliminate denormalized floats --- */
+/* pure arithmetic flushing, fastest with -ffast-math */
+#define	BSE_FLOAT_FLUSH(mutable_float)		BSE_FLOAT_FLUSH_with_threshold (mutable_float)
+#define	BSE_DOUBLE_FLUSH(mutable_double)	BSE_DOUBLE_FLUSH_with_threshold (mutable_double)
+#if 0	/* may be slow in non-inlined functions */
+#define	BSE_FLOAT_FLUSH(mutable_float)		BSE_FLOAT_FLUSH_with_cond (mutable_float)
+#define	BSE_DOUBLE_FLUSH(mutable_double)	BSE_DOUBLE_FLUSH_with_cond (mutable_double)
+#endif
+#if 0	/* branching may hurt performance in excessively inlined code */
+#define	BSE_FLOAT_FLUSH(mutable_float)		BSE_FLOAT_FLUSH_with_if (mutable_float)
+#define	BSE_DOUBLE_FLUSH(mutable_double)	BSE_DOUBLE_FLUSH_with_if (mutable_double)
+#endif
 
 /* --- rounding --- */
 typedef	unsigned short int	BseFpuState;
@@ -185,6 +200,60 @@ static const union { unsigned char c[8]; double d; } _bse_dinf_union = { _BSE_DO
 static const union { unsigned char c[4]; float f; }  _bse_fnan_union = { _BSE_FLOAT_NAN_BYTES };
 static const union { unsigned char c[4]; float f; }  _bse_finf_union = { _BSE_FLOAT_INF_BYTES };
 
+/* get structured parts of floating point numbers */
+#if __cplusplus
+extern inline BseFloatIEEE754  BSE_FLOAT_PARTS  (register float  fvalue) { BseFloatIEEE754  fret = { fvalue }; return fret; }
+extern inline BseDoubleIEEE754 BSE_DOUBLE_PARTS (register double dvalue) { BseDoubleIEEE754 dret = { dvalue }; return dret; }
+#else
+#define	BSE_FLOAT_PARTS(f)		(((BseFloatIEEE754) (f)))
+#define	BSE_DOUBLE_PARTS(d)		(((BseDoubleIEEE754) (d)))
+#endif
+
+/* --- implementation details --- */
+static inline float
+bse_float_zap_denormal (register float  fval)
+{
+  if (G_UNLIKELY (BSE_FLOAT_IS_SUBNORMAL (fval)))
+    return 0;
+  else
+    return fval;
+}
+
+static inline double
+bse_double_zap_denormal	(register double dval)
+{
+  if (G_UNLIKELY (BSE_DOUBLE_IS_SUBNORMAL (dval)))
+    return 0;
+  else
+    return dval;
+}
+
+/* use float arithmetic cancellation to eliminate denormals */
+#define	BSE_FLOAT_FLUSH_with_threshold(mutable_float)	do { 	\
+  volatile float __forced_float = 1e-29 + mutable_float;	\
+  mutable_float = __forced_float - 1e-29;			\
+} while (0)
+#define	BSE_DOUBLE_FLUSH_with_threshold(mutable_double) do {	\
+  volatile double __forced_double = 1e-288 + mutable_double;	\
+  mutable_double = __forced_double - 1e-288;			\
+} while (0)
+/* substitute with 0 beyond a certain threashold greater than possible denormals */
+#define BSE_FLOAT_FLUSH_with_cond(mutable_float) do {     			 \
+  mutable_float = G_UNLIKELY (fabs (mutable_float) < 1e-32) ? 0 : mutable_float; \
+} while (0)
+#define BSE_DOUBLE_FLUSH_with_cond(mutable_double) do {      			     \
+  mutable_double = G_UNLIKELY (fabs (mutable_double) < 1e-290) ? 0 : mutable_double; \
+} while (0)
+/* set everything to 0 beyond a certain threashold greater than possible denormals */
+#define	BSE_FLOAT_FLUSH_with_if(mutable_float) do { 	\
+  if (G_UNLIKELY (fabs (mutable_float) < 1e-32))	\
+    mutable_float = 0;					\
+} while (0)
+#define BSE_DOUBLE_FLUSH_with_if(mutable_double) do {	\
+  if (G_UNLIKELY (fabs (mutable_double) < 1e-290))	\
+    mutable_double = 0;					\
+} while (0)
+
 #if defined (__i386__) && defined (__GNUC__)
 static inline void
 bse_fpu_setround (BseFpuState *cw)
