@@ -150,7 +150,7 @@ void          bse_item_set_property_undoable (BseItem         *self,
 /* undo admin functions */
 BseUndoStack* bse_item_undo_open             (gpointer         item,
                                               const gchar     *format,
-                                              ...);
+                                              ...) G_GNUC_PRINTF (2, 3);
 void          bse_item_undo_close            (BseUndoStack    *ustack);
 /* undo helper functions */
 void          bse_item_push_undo_proc        (gpointer         item,
@@ -167,6 +167,7 @@ void          bse_item_push_undo_storage     (BseItem         *self,
 /* convenience */
 #define bse_item_set             bse_item_set_undoable
 #define bse_item_get             g_object_get
+BseMusicalTuningType bse_item_current_musical_tuning (BseItem     *self);
 
 G_END_DECLS
 
