@@ -16,7 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 #include "bseladspamodule.h"
-
+#include "bseblockutils.hh"
 #include "bsecategories.h"
 #include "bseengine.h"
 #include "bsemathsignal.h"
@@ -68,7 +68,8 @@ BSE_BUILTIN_TYPE (BseLadspaModule)
   type = bse_type_register_static (BSE_TYPE_SOURCE,
 				   "BseLadspaModule",
 				   "LADSPA Module base type",
-				   &type_info);
+                                   __FILE__, __LINE__,
+                                   &type_info);
   return type;
 }
 
@@ -188,12 +189,12 @@ bse_ladspa_module_class_init_from_info (BseLadspaModuleClass *ladspa_module_clas
 	  if (port->concert_a)
 	    {
 	      /* when defaulting to A', we probably have note-aligned port values */
-	      gint min_note = bse_note_from_freq_bounded (minimum);
-	      gint max_note = bse_note_from_freq_bounded (maximum);
+	      gint min_note = bse_note_from_freq_bounded (BSE_MUSICAL_TUNING_12_TET, minimum);
+	      gint max_note = bse_note_from_freq_bounded (BSE_MUSICAL_TUNING_12_TET, maximum);
 	      if (max_note - min_note > 2)
 		{
 		  gchar *ident2 = g_strconcat (port->ident, "-note", NULL);
-		  pspec2 = sfi_pspec_note (ident2, port->name, NULL,
+		  pspec2 = sfi_pspec_note (ident2, port->name, _("Note values are converted to Hertz according to the current musical tuning"),
 					   BSE_KAMMER_NOTE, min_note, max_note, FALSE,
 					   SFI_PARAM_GUI);
 		  g_param_spec_set_qdata (pspec2, quark_notify_sibling, pspec);
@@ -241,8 +242,9 @@ bse_ladspa_module_class_init_from_info (BseLadspaModuleClass *ladspa_module_clas
 }
 
 static gfloat
-ladspa_value_get_float (const GValue  *value,
-			BseLadspaPort *port)
+ladspa_value_get_float (BseLadspaModule *self,
+                        const GValue    *value,
+			BseLadspaPort   *port)
 {
   switch (sfi_categorize_type (G_VALUE_TYPE (value)))
     {
@@ -250,7 +252,7 @@ ladspa_value_get_float (const GValue  *value,
       return sfi_value_get_bool (value);
     case SFI_SCAT_INT:
       if (port->frequency && port->concert_a)	/* is note */
-	return bse_note_to_freq (sfi_value_get_int (value));
+	return bse_note_to_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), sfi_value_get_int (value));
       else
 	return sfi_value_get_int (value);
     case SFI_SCAT_REAL:
@@ -262,7 +264,8 @@ ladspa_value_get_float (const GValue  *value,
 }
 
 static void
-ladspa_value_set_float (GValue        *value,
+ladspa_value_set_float (BseLadspaModule *self,
+                        GValue        *value,
 			BseLadspaPort *port,
 			gfloat         v_float)
 {
@@ -273,7 +276,7 @@ ladspa_value_set_float (GValue        *value,
       break;
     case SFI_SCAT_INT:
       if (port->frequency && port->concert_a)	/* is note */
-	sfi_value_set_int (value, bse_note_from_freq (v_float));
+	sfi_value_set_int (value, bse_note_from_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), v_float));
       else
 	sfi_value_set_int (value, v_float >= 0 ? v_float + 0.5 : v_float - 0.5);
       break;
@@ -298,7 +301,7 @@ ladspa_derived_init (BseLadspaModule *self)
       GValue tmp = { 0, };
       g_value_init (&tmp, G_PARAM_SPEC_VALUE_TYPE (pspec));
       g_param_value_set_default (pspec, &tmp);
-      self->cvalues[i] = ladspa_value_get_float (&tmp, class->bli->cports + i);
+      self->cvalues[i] = ladspa_value_get_float (self, &tmp, class->bli->cports + i);
       g_value_unset (&tmp);
     }
 }
@@ -322,7 +325,7 @@ ladspa_derived_get_property (GObject    *object,
   guint i = param_id - 1;
   if (i >= class->bli->n_cports)
     i = (guint) g_param_spec_get_qdata (pspec, quark_value_index);
-  ladspa_value_set_float (value, class->bli->cports + i, self->cvalues[i]);
+  ladspa_value_set_float (self, value, class->bli->cports + i, self->cvalues[i]);
 }
 
 typedef struct
@@ -333,8 +336,8 @@ typedef struct
   gfloat	*ibuffers;
   gfloat         cvalues[1];	/* flexible array */
 } LadspaData;
-#define	LADSPA_DATA_SIZE(bli)	 (sizeof (LadspaData) + (MAX (bli->n_cports, 1) - 1) * sizeof (gfloat))
-#define	LADSPA_CVALUES_SIZE(bli) (bli->n_cports * sizeof (gfloat))
+#define	LADSPA_DATA_SIZE(bli)	  (sizeof (LadspaData) + (MAX (bli->n_cports, 1) - 1) * sizeof (gfloat))
+#define	LADSPA_CVALUES_COUNT(bli) (bli->n_cports /* * sizeof (gfloat) */)
 
 static void
 ladspa_module_access (BseModule *module,        /* EngineThread */
@@ -343,7 +346,7 @@ ladspa_module_access (BseModule *module,        /* EngineThread */
   LadspaData *ldata = module->user_data;
   LadspaData *cdata = data;
   /* this runs in the Gsl Engine threads */
-  memcpy (ldata->cvalues, cdata->cvalues, LADSPA_CVALUES_SIZE (ldata->bli));
+  bse_block_copy_float (LADSPA_CVALUES_COUNT (ldata->bli), ldata->cvalues, cdata->cvalues);
 }
 
 static void
@@ -359,14 +362,14 @@ ladspa_derived_set_property (GObject      *object,
   guint i = param_id - 1;
   if (i >= class->bli->n_cports)
     i = (guint) g_param_spec_get_qdata (pspec, quark_value_index);
-  self->cvalues[i] = ladspa_value_get_float (value, class->bli->cports + i);
+  self->cvalues[i] = ladspa_value_get_float (self, value, class->bli->cports + i);
   if (pspec2)
     g_object_notify (object, pspec2->name);
   /* update modules in all contexts with the new control values */
   if (BSE_SOURCE_PREPARED (self))
     {
       LadspaData *cdata = g_malloc0 (LADSPA_DATA_SIZE (class->bli));
-      memcpy (cdata->cvalues, self->cvalues, LADSPA_CVALUES_SIZE (class->bli));
+      bse_block_copy_float (LADSPA_CVALUES_COUNT (class->bli), cdata->cvalues, self->cvalues);
       bse_source_access_modules (BSE_SOURCE (self),
 				 ladspa_module_access,
 				 cdata, g_free,
@@ -484,7 +487,7 @@ ladspa_derived_context_create (BseSource *source,
   for (i = 0; i < bli->n_cports; i++)
     bli->connect_port (ldata->handle, bli->cports[i].port_index, ldata->cvalues + i);
   /* initialize control ports */
-  memcpy (ldata->cvalues, self->cvalues, LADSPA_CVALUES_SIZE (bli));
+  bse_block_copy_float (LADSPA_CVALUES_COUNT (bli), ldata->cvalues, self->cvalues);
   /* allocate input audio buffers */
   ldata->ibuffers = g_new (gfloat, class->gsl_class->n_istreams * bse_engine_block_size ());
   /* connect input audio ports */
