@@ -21,7 +21,7 @@
 #define __BSE_MATH_H__
 
 #include <bse/bsedefs.h>
-#include <bse/bseieee754.h> /* provides math.h */
+#include <bse/bseieee754.h> 	/* provides math.h */
 
 G_BEGIN_DECLS
 
@@ -31,6 +31,7 @@ G_BEGIN_DECLS
 #define BSE_PI_DIV_2                  (1.570796326794896619231321691639751442099)    // pi/2
 #define BSE_2_DIV_PI                  (0.6366197723675813430755350534900574481378)   // 2/pi
 #define BSE_2_DIV_SQRT_PI             (1.128379167095512573896158903121545171688)    // 2/sqrt(pi)
+#define BSE_2_DIV_LN2                 (2.88539008177792681471984936200378427485329)  // 2/ln(2)
 #define BSE_PI_DIV_4                  (0.7853981633974483096156608458198757210493)   // pi/4
 #define BSE_E                         (2.718281828459045235360287471352662497757)    // e^1
 #define BSE_LOG2E                     (1.442695040888963407359924681001892137427)    // log_2(e^1)
@@ -38,6 +39,7 @@ G_BEGIN_DECLS
 #define BSE_LN2                       (0.6931471805599453094172321214581765680755)   // ln(2)
 #define BSE_SQRT2                     (1.41421356237309504880168872420969807857)     // sqrt(2)
 #define BSE_1_DIV_SQRT2               (0.7071067811865475244008443621048490392848)   // 1/sqrt(2)
+#define BSE_LN4                       (1.386294361119890618834464242916353136151)    // ln(4)
 #define BSE_LN10                      (2.302585092994045684017991454684364207601)    // ln(10)
 #define BSE_LOG2_10                   (3.321928094887362347870319429489390175865)    // log_2(10)
 #define BSE_LOG2POW20_10              (0.1660964047443681173935159714744695087932)   // log_2(10)/20
@@ -46,6 +48,9 @@ G_BEGIN_DECLS
 #define BSE_LN_2_POW_1_DIV_1200_d     (5.776226504666210911810267678818138067296e-4) // ln(2^(1/1200))
 #define BSE_2_POW_1_DIV_72            (1.009673533228510862192521401118605073603)    // 2^(1/72)
 #define BSE_LN_2_POW_1_DIV_72         (9.62704417444368485301711279803023011216e-3)  // ln(2^(1/72))
+#define BSE_DECIBEL20_FACTOR          (8.68588963806503655302257837833210164588794)  // 20.0 / ln (10.0)
+#define BSE_DECIBEL10_FACTOR          (4.34294481903251827651128918916605082294397)  // 10.0 / ln (10.0)
+#define BSE_COMPLEX_ONE               (bse_complex (1, 0))
 
 /* --- structures --- */
 typedef struct {
@@ -160,6 +165,12 @@ double                 bse_bit_depth_epsilon    (guint          n_bits);  /* 1..
 gint                   bse_rand_int             (void);                   /* +-G_MAXINT */
 gfloat                 bse_rand_float           (void);                   /* -1.0..1.0 */
 gint                   bse_rand_bool            (void);                   /* random bit */
+void                   bse_float_gnuplot        (const char    *file_name,
+                                                 double         xstart,
+                                                 double         xstep,
+                                                 unsigned int   n_ypoints,
+                                                 const float   *ypoints);
+
 
 /* --- implementations --- */
 static inline BseComplex
