@@ -81,6 +81,7 @@ BSE_BUILTIN_TYPE (BsePcmInput)
                                          "BsePcmInput",
                                          "Stereo PCM sound input module, per default, signals from this "
                                          "module originate from recording on the standard soundcard",
+                                         __FILE__, __LINE__,
                                          &pcm_input_info);
   bse_categories_register_stock_module (N_("/Input & Output/PCM Input"), type, mic_pixstream);
   return type;
@@ -116,7 +117,7 @@ bse_pcm_input_class_init (BsePcmInputClass *class)
 			      sfi_pspec_real ("gain_volume_dB", "Input Gain [dB]", NULL,
 					      0,
 					      BSE_MIN_VOLUME_dB, BSE_MAX_VOLUME_dB,
-					      BSE_GCONFIG (step_volume_dB),
+                                              0.1,
 					      SFI_PARAM_GUI ":dial"));
   bse_object_class_add_param (object_class, "Adjustments",
 			      PARAM_MVOLUME_PERC,
