@@ -16,6 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 #include "bsepcmwriter.h"
+#include "bseserver.h"
 #include "gsldatautils.h"
 
 #include <errno.h>
@@ -55,7 +56,8 @@ BSE_BUILTIN_TYPE (BsePcmWriter)
   return bse_type_register_static (BSE_TYPE_ITEM,
 				   "BsePcmWriter",
 				   "PCM writer",
-				   &pcm_writer_info);
+                                   __FILE__, __LINE__,
+                                   &pcm_writer_info);
 }
 
 static void
@@ -94,7 +96,8 @@ BseErrorType
 bse_pcm_writer_open (BsePcmWriter *self,
 		     const gchar  *file,
 		     guint         n_channels,
-		     guint         sample_freq)
+		     guint         sample_freq,
+                     uint64        recorded_maximum)
 {
   BseErrorType error;
   gint fd;
@@ -105,15 +108,16 @@ bse_pcm_writer_open (BsePcmWriter *self,
   g_return_val_if_fail (n_channels > 0, BSE_ERROR_INTERNAL);
   g_return_val_if_fail (sample_freq >= 1000, BSE_ERROR_INTERNAL);
 
-  SFI_SYNC_LOCK (&self->mutex);
+  sfi_mutex_lock (&self->mutex);
 
   error = 0;
 
   self->n_bytes = 0;
+  self->recorded_maximum = recorded_maximum;
   fd = open (file, O_WRONLY | O_CREAT | O_TRUNC, 0666);
   if (fd < 0)
     {
-      SFI_SYNC_UNLOCK (&self->mutex);
+      sfi_mutex_unlock (&self->mutex);
       return bse_error_from_errno (errno, BSE_ERROR_FILE_OPEN_FAILED);
     }
 
@@ -121,14 +125,14 @@ bse_pcm_writer_open (BsePcmWriter *self,
   if (errno)
     {
       close (fd);
-      SFI_SYNC_UNLOCK (&self->mutex);
+      sfi_mutex_unlock (&self->mutex);
       return bse_error_from_errno (errno, BSE_ERROR_FILE_OPEN_FAILED);
     }
   self->fd = fd;
   self->open = TRUE;
   self->broken = FALSE;
 
-  SFI_SYNC_UNLOCK (&self->mutex);
+  sfi_mutex_unlock (&self->mutex);
   return BSE_ERROR_NONE;
 }
 
@@ -138,15 +142,22 @@ bse_pcm_writer_close (BsePcmWriter *self)
   g_return_if_fail (BSE_IS_PCM_WRITER (self));
   g_return_if_fail (self->open);
 
-  SFI_SYNC_LOCK (&self->mutex);
+  sfi_mutex_lock (&self->mutex);
   bse_wave_file_patch_length (self->fd, self->n_bytes);
   close (self->fd);
   self->fd = -1;
   self->open = FALSE;
-  SFI_SYNC_UNLOCK (&self->mutex);
+  sfi_mutex_unlock (&self->mutex);
   errno = 0;
 }
 
+static gboolean
+bsethread_halt_recording (gpointer data)
+{
+  bse_server_stop_recording (bse_server_get());
+  return false;
+}
+
 void
 bse_pcm_writer_write (BsePcmWriter *self,
 		      gsize         n_values,
@@ -159,21 +170,28 @@ bse_pcm_writer_write (BsePcmWriter *self,
   else
     return;
 
-  SFI_SYNC_LOCK (&self->mutex);
-  if (!self->broken)
+  sfi_mutex_lock (&self->mutex);
+  const uint bw = 2; /* 16bit */
+  if (!self->broken && (!self->recorded_maximum || self->n_bytes < bw * self->recorded_maximum))
     {
       guint j;
-      guint8 *dest = g_new (guint8, n_values * 2); /* 16bit */
-      guint n_bytes = gsl_conv_from_float_clip (GSL_WAVE_FORMAT_SIGNED_16,
-						G_BYTE_ORDER,
-						values,
-						dest,
-						n_values);
+      guint8 *dest = g_new (guint8, n_values * bw);
+      uint n_bytes = gsl_conv_from_float_clip (GSL_WAVE_FORMAT_SIGNED_16,
+                                               G_BYTE_ORDER,
+                                               values,
+                                               dest,
+                                               n_values);
+      if (self->recorded_maximum)
+        n_bytes = bw * MIN (n_bytes / bw, self->recorded_maximum - self->n_bytes / bw);
       do
 	j = write (self->fd, dest, n_bytes);
       while (j < 0 && errno == EINTR);
       if (j > 0)
-	self->n_bytes += j;
+        {
+          self->n_bytes += j;
+          if (self->recorded_maximum && self->n_bytes >= bw * self->recorded_maximum)
+            bse_idle_next (bsethread_halt_recording, NULL);
+        }
       g_free (dest);
       if (j < 0 && errno)
 	{
@@ -181,5 +199,5 @@ bse_pcm_writer_write (BsePcmWriter *self,
 	  self->broken = TRUE;
 	}
     }
-  SFI_SYNC_UNLOCK (&self->mutex);
+  sfi_mutex_unlock (&self->mutex);
 }
