@@ -44,10 +44,12 @@ struct _BseServer
   GSList	  *children;
 
   gchar		  *wave_file;
+  double           wave_seconds;
   
   guint		   dev_use_count;
-  BsePcmDevice    *pcm_device;
+  guint            log_messages : 1;
   guint            pcm_input_checked : 1;
+  BsePcmDevice    *pcm_device;
   BseModule       *pcm_imodule;
   BseModule       *pcm_omodule;
   BsePcmWriter	  *pcm_writer;
@@ -67,6 +69,10 @@ BseProject*	bse_server_create_project		(BseServer	*server,
 							 const gchar	*name);
 BseProject*	bse_server_find_project			(BseServer	*server,
 							 const gchar	*name);
+void    	bse_server_stop_recording		(BseServer	*server);
+void            bse_server_start_recording              (BseServer      *server,
+                                                         const char     *wave_file,
+                                                         double          n_seconds);
 BseErrorType	bse_server_open_devices			(BseServer	*server);
 void		bse_server_close_devices		(BseServer	*server);
 BseModule*	bse_server_retrieve_pcm_output_module	(BseServer	*server,
@@ -107,13 +113,19 @@ void		bse_server_script_error			(BseServer	    *server,
 							 const gchar	    *script_name,
 							 const gchar	    *proc_name,
 							 const gchar        *reason);
-void		bse_server_user_message		        (BseServer	    *server,
+void		bse_server_send_message	                (BseServer	    *server,
+                                                         const BseMessage   *umsg);
+void		bse_server_message		        (BseServer	    *server,
                                                          const gchar        *log_domain,
-                                                         BseUserMsgType      msg_type,
+                                                         BseMsgType          msg_type,
+                                                         const gchar        *title,
+                                                         const gchar        *primary,
+                                                         const gchar        *secondary,
+                                                         const gchar        *details,
                                                          const gchar        *config_blurb,
-                                                         const gchar        *message,
-                                                         gint                pid,
-                                                         const gchar        *process_name);
+                                                         BseJanitor         *janitor,
+                                                         const gchar        *process_name,
+                                                         gint                pid);
 BseErrorType	bse_server_run_remote			(BseServer	    *server,
 							 const gchar	    *process_name,
 							 SfiRing	    *params,
