@@ -46,6 +46,8 @@ struct _BseSong
   guint		    numerator;
   guint		    denominator;
   gfloat            bpm;
+
+  BseMusicalTuningType musical_tuning;
   
   SfiRing          *parts;              /* of type BsePart* */
   SfiRing          *busses;             /* of type BseBus* */
@@ -54,7 +56,7 @@ struct _BseSong
   BseSource	   *postprocess;
   BseSource	   *output;
 
-  BseSNet         *pnet;
+  BseSNet          *pnet;
 
   /* song position pointer */
   SfiInt	    last_position;
@@ -72,6 +74,7 @@ struct _BseSong
   gdouble	    delta_stamp_SL;	/* start + delta_stamp => tick */
   guint		    tick_SL;		/* tick at stamp_SL */
   guint             sequencer_owns_refcount_SL : 1;
+  guint             sequencer_underrun_detected_SL : 1;
   guint		    loop_enabled_SL : 1;
   SfiInt	    loop_left_SL;	/* left loop tick */
   SfiInt	    loop_right_SL;	/* left loop tick */
