@@ -34,6 +34,7 @@ enum
   PROP_PHASE,
   PROP_BASE_FREQ,
   PROP_BASE_NOTE,
+  PROP_TRANSPOSE,
   PROP_FINE_TUNE,
   PROP_FM_PERC,
   PROP_FM_EXP,
@@ -69,6 +70,7 @@ static void	bse_standard_osc_update_modules	(BseStandardOsc		*standard_osc,
 /* --- variables --- */
 static gpointer	    parent_class = NULL;
 static const gfloat osc_table_freqs[] = {
+  /* FIXME */
   BSE_KAMMER_FREQUENCY,
   BSE_KAMMER_FREQUENCY / 2.0,
   BSE_KAMMER_FREQUENCY / 4.0,
@@ -104,7 +106,8 @@ BSE_BUILTIN_TYPE (BseStandardOsc)
 				   "BseStandardOsc",
 				   _("StandardOsc is the BSE basis oscillator which supports various types "
                                      "of wave forms and modulation inputs."),
-				   &type_info);
+                                   __FILE__, __LINE__,
+                                   &type_info);
   bse_categories_register_stock_module (N_("/Audio Sources/Standard Oscillator"), type, osc_pixstream);
   return type;
 }
@@ -139,15 +142,22 @@ bse_standard_osc_class_init (BseStandardOscClass *class)
 					      SFI_PARAM_STANDARD ":f:dial:skip-default"));
   bse_object_class_add_param (object_class, _("Base Frequency"),
 			      PROP_BASE_FREQ,
-			      bse_param_spec_freq_simple ("base_freq", _("Frequency"), _("Number of oscillator cycles per second"),
+			      bse_param_spec_freq_simple ("base_freq", _("Frequency"),
+                                                          _("Oscillator frequency in Hertz, i.e. the number of oscillator cycles per second"),
 							  SFI_PARAM_STANDARD ":f:dial"));
   bse_object_class_add_param (object_class, _("Base Frequency"),
 			      PROP_BASE_NOTE,
-			      bse_pspec_note_simple ("base_note", _("Note"), _("Musical notation corresponding to the oscillator frequency"),
+			      bse_pspec_note_simple ("base_note", _("Note"),
+                                                     _("Oscillator frequency as note, converted to Hertz according to the current musical tuning"),
                                                      SFI_PARAM_GUI));
+  bse_object_class_add_param (object_class, _("Base Frequency"),
+			      PROP_TRANSPOSE,
+			      sfi_pspec_int ("transpose", _("Transpose"), _("Transposition of the oscillator frequency in semitones"),
+					     0, BSE_MIN_TRANSPOSE, BSE_MAX_TRANSPOSE, 12,
+					     SFI_PARAM_STANDARD ":f:dial:skip-default"));
   bse_object_class_add_param (object_class, _("Base Frequency"),
 			      PROP_FINE_TUNE,
-			      sfi_pspec_int ("fine_tune", _("Fine Tune"), _("Amount of detuning in cent (hundredth part of a note)"),
+			      sfi_pspec_int ("fine_tune", _("Fine Tune"), _("Amount of detuning in cent (hundredth part of a semitone)"),
 					     0, BSE_MIN_FINE_TUNE, BSE_MAX_FINE_TUNE, 10,
 					     SFI_PARAM_STANDARD ":f:dial:skip-default"));
   bse_object_class_add_param (object_class, _("Modulation"),
@@ -214,6 +224,7 @@ bse_standard_osc_init (BseStandardOsc *self)
   self->config.self_fm_strength = 0;
   self->config.pulse_width = 0.5;
   self->config.pulse_mod_strength = 0;
+  self->transpose = 0;
   self->fm_strength = 0;
   self->n_octaves = 1;
 }
@@ -242,13 +253,17 @@ bse_standard_osc_set_property (GObject      *object,
       g_object_notify (self, "base_note");
       break;
     case PROP_BASE_NOTE:
-      self->config.cfreq = bse_note_to_freq (sfi_value_get_note (value));
+      self->config.cfreq = bse_note_to_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), sfi_value_get_note (value));
       self->config.cfreq = MAX (self->config.cfreq, BSE_MIN_OSC_FREQUENCY);
       bse_standard_osc_update_modules (self, FALSE, NULL);
       g_object_notify (self, "base_freq");
-      if (bse_note_from_freq (self->config.cfreq) != sfi_value_get_note (value))
+      if (bse_note_from_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), self->config.cfreq) != sfi_value_get_note (value))
 	g_object_notify (self, "base_note");
       break;
+    case PROP_TRANSPOSE:
+      self->transpose = sfi_value_get_int (value);
+      bse_standard_osc_update_modules (self, FALSE, NULL);
+      break;
     case PROP_FINE_TUNE:
       self->config.fine_tune = sfi_value_get_int (value);
       bse_standard_osc_update_modules (self, FALSE, NULL);
@@ -303,7 +318,10 @@ bse_standard_osc_get_property (GObject    *object,
       sfi_value_set_real (value, self->config.cfreq);
       break;
     case PROP_BASE_NOTE:
-      sfi_value_set_note (value, bse_note_from_freq (self->config.cfreq));
+      sfi_value_set_note (value, bse_note_from_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), self->config.cfreq));
+      break;
+    case PROP_TRANSPOSE:
+      sfi_value_set_int (value, self->transpose);
       break;
     case PROP_FINE_TUNE:
       sfi_value_set_int (value, self->config.fine_tune);
@@ -342,6 +360,7 @@ bse_standard_osc_prepare (BseSource *source)
 					     bse_window_blackman,
 					     G_N_ELEMENTS (osc_table_freqs),
 					     osc_table_freqs);
+  self->config.transpose_factor = bse_transpose_factor (bse_source_prepared_musical_tuning (BSE_SOURCE (self)), self->transpose);
   
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (parent_class)->prepare (source);
@@ -387,6 +406,7 @@ bse_standard_osc_update_modules (BseStandardOsc *self,
     {
       OscConfigData cdata;
       
+      self->config.transpose_factor = bse_transpose_factor (bse_source_prepared_musical_tuning (BSE_SOURCE (self)), self->transpose);
       cdata.config = self->config;
       if (recreate_table)
 	{
