@@ -55,9 +55,14 @@ bse_super_init (BseSuper *super,
   bse_super_objects = g_slist_prepend (bse_super_objects, super);
   
   /* we want Unnamed-xxx default unames */
-  bse_item_set (super,
-		"uname", "Unnamed",
-		NULL);
+  bse_item_set (super, "uname", "Unnamed", NULL);
+  /* default-fill fields */
+  const char *value = BSE_GCONFIG (author_default);
+  if (value && value[0])
+    bse_item_set (super, "author", value, NULL);
+  value = BSE_GCONFIG (license_default);
+  if (value && value[0])
+    bse_item_set (super, "license", value, NULL);
 }
 
 static void
@@ -151,6 +156,19 @@ super_modified (BseSuper *super,
   super->mod_time = MAX (super->mod_time, stamp);
 }
 
+static void
+super_compat_setup (BseItem               *item,
+                    guint                  vmajor,
+                    guint                  vminor,
+                    guint                  vmicro)
+{
+  if (BSE_VERSION_CMP (vmajor, vminor, vmicro, 0, 7, 0) < 0)
+    bse_item_set (item,
+                  "author", "",
+                  "license", "",
+                  NULL);
+}
+
 static void
 super_compat_finish (BseSuper       *super,
                      guint           vmajor,
@@ -164,6 +182,7 @@ bse_super_class_init (BseSuperClass *class)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (class);
   BseObjectClass *object_class = BSE_OBJECT_CLASS (class);
+  BseItemClass *item_class = BSE_ITEM_CLASS (class);
   // BseSourceClass *source_class = BSE_SOURCE_CLASS (class);
   
   parent_class = g_type_class_peek_parent (class);
@@ -175,19 +194,21 @@ bse_super_class_init (BseSuperClass *class)
   gobject_class->get_property = bse_super_get_property;
   gobject_class->finalize = bse_super_finalize;
 
+  item_class->compat_setup = super_compat_setup;
+
   class->modified = super_modified;
   class->compat_finish = super_compat_finish;
   
   bse_object_class_add_param (object_class, NULL,
 			      PARAM_AUTHOR,
 			      sfi_pspec_string ("author", _("Author"), _("Person changing or creating this object"),
-						NULL,
-						SFI_PARAM_STANDARD ":skip-default"));
+						"",
+						SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, NULL,
 			      PARAM_LICENSE,
 			      sfi_pspec_string ("license", _("License"), _("Copyright license applying to this object"),
-						NULL,
-						SFI_PARAM_STANDARD ":skip-default"));
+						"",
+						SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, NULL,
 			      PARAM_COPYRIGHT,
 			      sfi_pspec_string ("copyright", NULL, NULL, NULL, "w")); // COMPAT-FIXME: remove around 0.7.0
@@ -220,5 +241,6 @@ BSE_BUILTIN_TYPE (BseSuper)
   return bse_type_register_abstract (BSE_TYPE_CONTAINER,
                                      "BseSuper",
                                      "Base type for item managers",
+                                     __FILE__, __LINE__,
                                      &super_info);
 }
