@@ -31,23 +31,27 @@
 
 /* --- record utils --- */
 BseNoteDescription*
-bse_note_description (SfiInt note,
-                      gint   fine_tune)
+bse_note_description (BseMusicalTuningType   musical_tuning,
+                      int                    note,
+                      int                    fine_tune)
 {
   BseNoteDescription *info = bse_note_description_new ();
 
+  info->musical_tuning = musical_tuning;
   if (note >= BSE_MIN_NOTE && note <= BSE_MAX_NOTE)
     {
       gchar letter;
       info->note = note;
+      gboolean black_semitone = false;
       bse_note_examine (info->note,
                         &info->octave,
                         &info->semitone,
-                        &info->upshift,
+                        &black_semitone,
                         &letter);
+      info->upshift = black_semitone;
       info->letter = letter;
       info->fine_tune = CLAMP (fine_tune, BSE_MIN_FINE_TUNE, BSE_MAX_FINE_TUNE);
-      info->freq = bse_note_to_tuned_freq (info->note, info->fine_tune);
+      info->freq = bse_note_to_tuned_freq (musical_tuning, info->note, info->fine_tune);
       info->name = bse_note_to_string (info->note);
       info->max_fine_tune = BSE_MAX_FINE_TUNE;
       info->kammer_note = BSE_KAMMER_NOTE;
@@ -315,12 +319,11 @@ bse_icon_from_pixdata (const BsePixdata *pixdata)
       const guint8 *rle_buffer = pixdata->encoded_pix_data;
       guint8 *image_buffer = icon->pixels->bytes;
       guint8 *image_limit = image_buffer + icon->width * icon->height * bpp;
-      gboolean check_overrun = FALSE;
       
       while (image_buffer < image_limit)
 	{
 	  guint length = *(rle_buffer++);
-	  
+          gboolean check_overrun = FALSE;
 	  if (length & 128)
 	    {
 	      length = length - 128;
@@ -353,9 +356,9 @@ bse_icon_from_pixdata (const BsePixdata *pixdata)
 	      image_buffer += length;
 	      rle_buffer += length;
 	    }
-	}
-      if (check_overrun)
-	g_warning (G_GNUC_PRETTY_FUNCTION "(): `pixdata' encoding screwed");
+          if (check_overrun)
+            g_warning (G_GNUC_PRETTY_FUNCTION "(): `pixdata' encoding screwed");
+        }
     }
   else
     memcpy (icon->pixels->bytes, pixdata->encoded_pix_data, icon->width * icon->height * bpp);
@@ -697,6 +700,22 @@ bse_intern_path_user_data (const gchar *dir)
   return g_intern_strconcat (BSE_PATH_USER_DATA ("/"), dir, NULL);
 }
 
+const gchar*
+bse_intern_default_author (void)
+{
+  const char *user = g_get_user_name();
+  const char *name = g_get_real_name();
+  if (name && user && name[0] && strcmp (user, name) != 0)
+    return g_intern_string (name);
+  return g_intern_static_string ("");
+}
+
+const gchar*
+bse_intern_default_license (void)
+{
+  return g_intern_static_string ("Creative Commons Attribution 2.5 (http://creativecommons.org/licenses/by/2.5/)");
+}
+
 void
 bse_bbuffer_puts (gchar        bbuffer[BSE_BBUFFER_SIZE],
 		  const gchar *string)
