@@ -17,10 +17,9 @@
  * Boston, MA 02111-1307, USA.
  */
 #include "gsldatacache.h"
-
+#include "bsemain.h"
 #include "gslcommon.h"
 #include "gsldatahandle.h"
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -32,7 +31,7 @@
 /* --- macros --- */
 #define	NODEP_INDEX(dcache, node_p)	((node_p) - (dcache)->nodes)
 #define	UPPER_POWER2(n)			(sfi_alloc_upper_power2 (MAX (n, 4)))
-#define	CONFIG_NODE_SIZE()		(gsl_get_config ()->dcache_block_size)
+#define	CONFIG_NODE_SIZE()		(BSE_CONFIG (dcache_block_size))
 #define	AGE_EPSILON			(3)	/* must be < resident set */
 #define	LOW_PERSISTENCY_RESIDENT_SET    (5)
 
@@ -59,14 +58,14 @@
 /* --- prototypes --- */
 static void			dcache_free		(GslDataCache	*dcache);
 static GslDataCacheNode*	data_cache_new_node_L	(GslDataCache	*dcache,
-							 gsize		 offset,
+							 int64		 offset,
 							 guint		 pos,
 							 gboolean	 demand_load);
 
 
 /* --- variables --- */
-static SfiMutex	   global_dcache_mutex = { 0, };
-static SfiCond	   global_dcache_cond_node_filled = { 0, };
+static BirnetMutex	   global_dcache_mutex = { 0, };
+static BirnetCond	   global_dcache_cond_node_filled = { 0, };
 static SfiRing	  *global_dcache_list = NULL;
 static guint	   global_dcache_count = 0;
 static guint       global_dcache_n_aged_nodes = 0;
@@ -81,7 +80,7 @@ _gsl_init_data_caches (void)
   g_assert (initialized == FALSE);
   initialized++;
 
-  g_static_assert (AGE_EPSILON < LOW_PERSISTENCY_RESIDENT_SET);
+  BIRNET_STATIC_ASSERT (AGE_EPSILON < LOW_PERSISTENCY_RESIDENT_SET);
   sfi_cond_init (&global_dcache_cond_node_filled);
   sfi_mutex_init (&global_dcache_mutex);
 }
@@ -252,7 +251,7 @@ gsl_data_cache_unref (GslDataCache *dcache)
 
 static inline GslDataCacheNode**
 data_cache_lookup_nextmost_node_L (GslDataCache *dcache,
-				   gsize         offset)
+				   int64         offset)
 {
   if (dcache->n_nodes > 0)
     {
@@ -288,14 +287,14 @@ data_cache_lookup_nextmost_node_L (GslDataCache *dcache,
 
 static inline GslDataCacheNode*
 data_cache_new_node_L (GslDataCache *dcache,
-		       gsize	     offset,
+		       int64	     offset,
 		       guint	     pos,
 		       gboolean	     demand_load)
 {
   GslDataCacheNode **node_p, *dnode;
   GslDataType *data, *node_data;
   guint new_node_array_size, old_node_array_size = UPPER_POWER2 (dcache->n_nodes);
-  GslLong dhandle_length;
+  int64 dhandle_length;
   guint i, size;
   gint result;
 
@@ -335,8 +334,8 @@ data_cache_new_node_L (GslDataCache *dcache,
   GslDataCacheNode *prev_node = pos ? dcache->nodes[pos - 1] : NULL;
   if (prev_node)
     {
-      GslLong prev_node_size = dcache->node_size;
-      GslLong prev_node_offset = prev_node->offset;
+      int64 prev_node_size = dcache->node_size;
+      int64 prev_node_offset = prev_node->offset;
       GslDataType *prev_node_data = prev_node->data;
       
       /* padding around prev_node */
@@ -347,7 +346,7 @@ data_cache_new_node_L (GslDataCache *dcache,
       /* check for overlap */
       if (offset < prev_node_offset + prev_node_size)
         {
-          GslLong overlap = prev_node_offset + prev_node_size - offset;
+          int64 overlap = prev_node_offset + prev_node_size - offset;
           memcpy (data, prev_node_data + offset - prev_node_offset, overlap * sizeof (data[0]));
           size -= overlap;
           offset += overlap;
@@ -387,7 +386,7 @@ data_cache_new_node_L (GslDataCache *dcache,
 
 GslDataCacheNode*
 gsl_data_cache_ref_node (GslDataCache       *dcache,
-			 gsize               offset,
+			 int64               offset,
 			 GslDataCacheRequest load_request)
 {
   GslDataCacheNode **node_p, *node;
@@ -546,7 +545,7 @@ gsl_data_cache_unref_node (GslDataCache     *dcache,
   if (check_cache)
     {
       guint node_size = CONFIG_NODE_SIZE ();
-      guint cache_mem = gsl_get_config ()->dcache_cache_memory;
+      guint cache_mem = BSE_CONFIG (dcache_cache_memory);
       guint current_mem;
 
       GSL_SPIN_LOCK (&global_dcache_mutex);
