@@ -16,8 +16,8 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+#include "topconfig.h"
 #include <bse/gsldatahandle-mad.h>
-
 #include "gslfilehash.h"
 #include <bse/gsldatautils.h>
 #include <assert.h>
@@ -31,7 +31,9 @@
 #include <string.h>
 #include <errno.h>
 
-#if	GSL_HAVE_LIBMAD
+BIRNET_STATIC_ASSERT (BSE_HAVE_LIBMAD + 42); // assert BSE_HAVE_LIBMAD2 is defined
+
+#if     BSE_HAVE_LIBMAD
 #include <mad.h>
 
 
@@ -557,7 +559,7 @@ dh_mad_read (GslDataHandle *dhandle,
     }
   else /* something went wrong here, _badly_ */
     {
-      sfi_diag ("MAD-init: pcm position screwed (pos: %lu, handle-pos: %lu), aborting read",
+      sfi_diag ("MAD-init: pcm position screwed (pos: %llu, handle-pos: %llu), aborting read",
                 pos, handle->pcm_pos);	
       return -1;
     }
@@ -624,7 +626,7 @@ dh_mad_coarse_seek (GslDataHandle *dhandle,
 	    }
 	}
 
-      MAD_DEBUG ("seek-done: at %lu (f:%lu) want %lu (f:%lu) got %lu (f:%lu) diff %ld (diff-requested %ld)",
+      MAD_DEBUG ("seek-done: at %llu (f:%llu) want %llu (f:%llu) got %llu (f:%llu) diff %lld (diff-requested %lld)",
 		 opos, opos / handle->frame_size,
 		 pos, pos / handle->frame_size,
 		 handle->pcm_pos, handle->pcm_pos / handle->frame_size,
@@ -671,6 +673,7 @@ static GslDataHandleFuncs dh_mad_vtable = {
   dh_mad_read,
   dh_mad_close,
   NULL,
+  NULL,
   dh_mad_destroy,
 };
 
@@ -772,7 +775,7 @@ gsl_data_handle_mad_version (void)
   return MAD_VERSION;
 }
 
-#else	/* !GSL_HAVE_LIBMAD */
+#else	/* !BSE_HAVE_LIBMAD */
 
 GslDataHandle*
 gsl_data_handle_new_mad_err (const gchar  *file_name,
@@ -798,7 +801,7 @@ gsl_data_handle_mad_version (void)
   return NULL;
 }
 
-#endif	/* !GSL_HAVE_LIBMAD */
+#endif	/* !BSE_HAVE_LIBMAD */
 
 GslDataHandle*
 gsl_data_handle_new_mad (const gchar  *file_name,
