@@ -58,12 +58,12 @@ static void	 bse_mixer_update_modules	(BseMixer	*self,
 
 /* --- Export to BSE --- */
 #include "./icons/mixer.c"
-BSE_REGISTER_OBJECT (BseMixer, BseSource, "/Modules/Routing/Mixer",
+BSE_REGISTER_OBJECT (BseMixer, BseSource, "/Modules/Routing/Mixer", "",
                      "The Mixer module sums up incomming signals, and allowes for fine "
                      "adjusted weighting (volume setting) of the input sources",
                      mixer_icon,
                      bse_mixer_class_init, NULL, bse_mixer_init);
-BSE_DEFINE_EXPORTS (BSE_PLUGIN_NAME);
+BSE_DEFINE_EXPORTS ();
 
 
 /* --- variables --- */
@@ -98,7 +98,7 @@ bse_mixer_class_init (BseMixerClass *class)
 			      sfi_pspec_real ("master_volume_dB", "Master [dB]", NULL,
 					      DEFAULT_DB_VOLUME,
 					      BSE_MIN_VOLUME_dB, BSE_MAX_VOLUME_dB,
-					      BSE_GCONFIG (step_volume_dB),
+					      0.1,
 					      SFI_PARAM_GUI ":dial"));
   bse_object_class_add_param (object_class, "Adjustments",
 			      PROP_MVOLUME_PERC,
@@ -130,7 +130,7 @@ bse_mixer_class_init (BseMixerClass *class)
 				  sfi_pspec_real (ident, label, NULL,
 						  DEFAULT_DB_VOLUME,
 						  BSE_MIN_VOLUME_dB, BSE_MAX_VOLUME_dB,
-						  BSE_GCONFIG (step_volume_dB),
+                                                  0.1,
 						  SFI_PARAM_GUI ":dial"));
       g_free (ident);
       g_free (label);
