@@ -1,5 +1,6 @@
 /* DavOrgan - DAV Additive Organ Synthesizer
  * Copyright (c) 1999, 2000, 2002 David A. Bartold and Tim Janik
+ * Copyright (c) 2006 Stefan Westerfeld
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Library General Public License as
@@ -19,6 +20,8 @@
 #include "davorgan.h"
 
 #include <bse/bseengine.h>
+#include <bse/bsemathsignal.h>
+#include <bse/bsemain.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -29,6 +32,8 @@ enum
   PARAM_0,
   PARAM_BASE_FREQ,
   PARAM_BASE_NOTE,
+  PARAM_TRANSPOSE,
+  PARAM_FINE_TUNE,
   PARAM_HARM0,
   PARAM_HARM1,
   PARAM_HARM2,
@@ -62,11 +67,11 @@ static void	   dav_organ_update_modules   (DavOrgan       *self);
 
 /* --- Export to DAV --- */
 #include "./icons/organ.c"
-BSE_REGISTER_OBJECT (DavOrgan, BseSource, "/Modules/Audio Sources/Organ",
+BSE_REGISTER_OBJECT (DavOrgan, BseSource, "/Modules/Audio Sources/Organ", "",
                      "DavOrgan is a modifiable additive organ synthesizer",
                      organ_icon,
                      dav_organ_class_init, NULL, dav_organ_init);
-BSE_DEFINE_EXPORTS (BSE_PLUGIN_NAME);
+BSE_DEFINE_EXPORTS ();
 
 
 /* --- variables --- */
@@ -100,13 +105,26 @@ dav_organ_class_init (DavOrganClass *class)
   source_class->context_create = dav_organ_context_create;
   source_class->reset = dav_organ_reset;
   
-  bse_object_class_add_param (object_class, "Base Frequency", PARAM_BASE_FREQ,
-			      bse_param_spec_freq ("base_freq", "Frequency", NULL,
+  bse_object_class_add_param (object_class, _("Base Frequency"), PARAM_BASE_FREQ,
+			      bse_param_spec_freq ("base_freq", _("Frequency"),
+                                                   _("Organ frequency in Hertz, i.e. the pitch of the base tone"),
 						   BSE_KAMMER_FREQUENCY, BSE_MIN_OSC_FREQUENCY, BSE_MAX_OSC_FREQUENCY,
 						   SFI_PARAM_STANDARD ":dial"));
-  bse_object_class_add_param (object_class, "Base Frequency",
+  bse_object_class_add_param (object_class, _("Base Frequency"),
                               PARAM_BASE_NOTE,
-                              bse_pspec_note_simple ("base_note", "Note", NULL, SFI_PARAM_GUI));
+                              bse_pspec_note_simple ("base_note", _("Note"),
+                                                     _("Organ frequency as note, converted to Hertz according to the current musical tuning"),
+                                                     SFI_PARAM_GUI));
+  bse_object_class_add_param (object_class, _("Base Frequency"),
+			      PARAM_TRANSPOSE,
+			      sfi_pspec_int ("transpose", _("Transpose"), _("Transposition of the frequency in semitones"),
+					     0, BSE_MIN_TRANSPOSE, BSE_MAX_TRANSPOSE, 12,
+					     SFI_PARAM_STANDARD ":f:dial:skip-default"));
+  bse_object_class_add_param (object_class, _("Base Frequency"),
+			      PARAM_FINE_TUNE,
+			      sfi_pspec_int ("fine_tune", _("Fine Tune"), _("Amount of detuning in cent (hundredth part of a semitone)"),
+					     0, BSE_MIN_FINE_TUNE, BSE_MAX_FINE_TUNE, 10,
+					     SFI_PARAM_STANDARD ":f:dial:skip-default"));
   bse_object_class_add_param (object_class, "Instrument flavour", PARAM_BRASS,
 			      sfi_pspec_bool ("brass", "Brass Sounds", "Changes the organ to sound more brassy",
                                               FALSE, SFI_PARAM_STANDARD));
@@ -141,6 +159,7 @@ dav_organ_init (DavOrgan *self)
   self->config.reed = FALSE;
   
   self->config.freq = BSE_KAMMER_FREQUENCY;
+  self->config.transpose_factor = 0; // updated when prepared
   self->config.harm0 = 1.0;
   self->config.harm1 = 36. / 127.;
   self->config.harm2 = 100. / 127.;
@@ -165,10 +184,18 @@ dav_organ_set_property (GObject      *object,
       dav_organ_update_modules (self);
       break;
     case PARAM_BASE_NOTE:
-      self->config.freq = bse_note_to_freq (sfi_value_get_note (value));
+      self->config.freq = bse_note_to_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), sfi_value_get_note (value));
       g_object_notify (G_OBJECT (self), "base_freq");
       dav_organ_update_modules (self);
       break;
+    case PARAM_TRANSPOSE:
+      self->transpose = sfi_value_get_int (value);
+      dav_organ_update_modules (self);
+      break;
+    case PARAM_FINE_TUNE:
+      self->config.fine_tune = sfi_value_get_int (value);
+      dav_organ_update_modules (self);
+      break;
     case PARAM_BRASS:
       self->config.brass = sfi_value_get_bool (value);
       dav_organ_update_modules (self);
@@ -225,7 +252,13 @@ dav_organ_get_property (GObject    *object,
       sfi_value_set_real (value, self->config.freq);
       break;
     case PARAM_BASE_NOTE:
-      sfi_value_set_note (value, bse_note_from_freq (self->config.freq));
+      sfi_value_set_note (value, bse_note_from_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), self->config.freq));
+      break;
+    case PARAM_TRANSPOSE:
+      sfi_value_set_int (value, self->transpose);
+      break;
+    case PARAM_FINE_TUNE:
+      sfi_value_set_int (value, self->config.fine_tune);
       break;
     case PARAM_BRASS:
       sfi_value_set_bool (value, self->config.brass);
@@ -319,9 +352,11 @@ dav_organ_class_unref_tables (DavOrganClass *class)
 static void
 dav_organ_prepare (BseSource *source)
 {
-  DavOrganClass *class = DAV_ORGAN_GET_CLASS (source);
+  DavOrgan *self = DAV_ORGAN (source);
+  DavOrganClass *class = DAV_ORGAN_GET_CLASS (self);
   
   dav_organ_class_ref_tables (class);
+  self->config.transpose_factor = bse_transpose_factor (bse_source_prepared_musical_tuning (source), self->transpose);
   
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (parent_class)->prepare (source);
@@ -345,11 +380,14 @@ dav_organ_update_modules (DavOrgan *self)
 {
   /* update organ data during runtime */
   if (BSE_SOURCE_PREPARED (self))
-    bse_source_update_modules (BSE_SOURCE (self),
-			       G_STRUCT_OFFSET (Organ, config),
-			       &self->config,
-			       sizeof (self->config),
-			       NULL);
+    {
+      self->config.transpose_factor = bse_transpose_factor (bse_source_prepared_musical_tuning (BSE_SOURCE (self)), self->transpose);
+      bse_source_update_modules (BSE_SOURCE (self),
+                                 G_STRUCT_OFFSET (Organ, config),
+                                 &self->config,
+                                 sizeof (self->config),
+                                 NULL);
+    }
 }
 
 static inline gfloat
@@ -365,6 +403,25 @@ table_pos (const gfloat *table,
   return table[*paccu >> 8];
 }
 
+static void
+dav_organ_reset_module (BseModule *module)
+{
+  Organ *organ = module->user_data;
+
+  guint32 rfactor = bse_main_args->allow_randomization ? 1 : 0;
+  guint32 mix_freq_256 = bse_engine_sample_freq() * 256;
+
+  /* to make all notes sound a bit different, randomize the initial phase of
+   * each harmonic (except if the user requested deterministic behaviour)
+   */
+  organ->harm0_paccu = rfactor * g_random_int_range (0, mix_freq_256);
+  organ->harm1_paccu = rfactor * g_random_int_range (0, mix_freq_256);
+  organ->harm2_paccu = rfactor * g_random_int_range (0, mix_freq_256);
+  organ->harm3_paccu = rfactor * g_random_int_range (0, mix_freq_256);
+  organ->harm4_paccu = rfactor * g_random_int_range (0, mix_freq_256);
+  organ->harm5_paccu = rfactor * g_random_int_range (0, mix_freq_256);
+}
+
 static void
 dav_organ_process (BseModule *module,
 		   guint      n_values)
@@ -376,14 +433,16 @@ dav_organ_process (BseModule *module,
   const gfloat *reed_table = organ->config.reed ? class->pulse_table : sine_table;
   const gfloat *ifreq = BSE_MODULE_IBUFFER (module, DAV_ORGAN_ICHANNEL_FREQ);
   gfloat *ovalues = BSE_MODULE_OBUFFER (module, DAV_ORGAN_OCHANNEL_MONO);
+  const gdouble transpose = organ->config.transpose_factor;
+  const gdouble fine_tune = bse_cent_factor (organ->config.fine_tune);
   guint freq_256, mix_freq_256;
   guint freq_256_harm0, freq_256_harm1;
   guint i;
   
   if (BSE_MODULE_ISTREAM (module, DAV_ORGAN_ICHANNEL_FREQ).connected)
-    freq_256 = BSE_FREQ_FROM_VALUE (ifreq[0]) * 256 + 0.5;
+    freq_256 = BSE_FREQ_FROM_VALUE (ifreq[0]) * transpose * fine_tune * 256 + 0.5;
   else
-    freq_256 = organ->config.freq * 256 + 0.5;
+    freq_256 = organ->config.freq * transpose * fine_tune * 256 + 0.5;
   mix_freq_256 = bse_engine_sample_freq() * 256;
   freq_256_harm0 = freq_256 / 2;
   freq_256_harm1 = freq_256;
@@ -441,7 +500,7 @@ dav_organ_context_create (BseSource *source,
     DAV_ORGAN_N_OCHANNELS,	/* n_ostreams */
     dav_organ_process,		/* process */
     NULL,                       /* process_defer */
-    NULL,                       /* reset */
+    dav_organ_reset_module,     /* reset */
     (BseModuleFreeFunc) g_free,	/* free */
     BSE_COST_NORMAL,		/* cost */
   };
