@@ -20,7 +20,6 @@
 #include "sfiprimitives.h"
 #include "sfiserial.h"
 #include "sfistore.h"
-#include "sfilog.h"
 #include <errno.h>
 #include <unistd.h>
 #include <string.h>
@@ -32,7 +31,7 @@
 #include <sys/wait.h>
 
 static SFI_MSG_TYPE_DEFINE (debug_comport, "comport", SFI_MSG_DEBUG, NULL);
-#define DEBUG(...)      sfi_debug (debug_comport, __VA_ARGS__)
+#define DEBUG(...)              sfi_debug (debug_comport, __VA_ARGS__)
 #define MASS_DEBUG(...) // DEBUG (__VA_ARGS__)          // log every communicated value
 
 /* define the io bottle neck (for writes) to a small value
@@ -130,10 +129,10 @@ sfi_com_port_from_pipe (const gchar *ident,
 
 void
 sfi_com_port_create_linked (const gchar *ident1,
-			    SfiThread   *thread1,
+			    BirnetThread   *thread1,
 			    SfiComPort **port1,
 			    const gchar *ident2,
-			    SfiThread   *thread2,
+			    BirnetThread   *thread2,
 			    SfiComPort **port2)
 {
   SfiComPortLink *link;
@@ -254,7 +253,7 @@ sfi_com_port_close_remote (SfiComPort *port,
     {
       SfiComPortLink *link = port->link;
       gboolean need_destroy;
-      SFI_SPIN_LOCK (&link->mutex);
+      sfi_mutex_lock (&link->mutex);
       if (port == link->port1)
 	{
 	  link->port1 = NULL;
@@ -267,7 +266,7 @@ sfi_com_port_close_remote (SfiComPort *port,
 	}
       link->ref_count--;
       need_destroy = link->ref_count == 0;
-      SFI_SPIN_UNLOCK (&link->mutex);
+      sfi_mutex_unlock (&link->mutex);
       port->link = NULL;
       if (need_destroy)
 	sfi_com_port_link_destroy (port->link);
@@ -387,12 +386,12 @@ sfi_com_port_send_bulk (SfiComPort   *port,
       SfiComPortLink *link = port->link;
       gboolean first = port == link->port1;
       SfiRing *target = NULL;
-      SfiThread *thread = NULL;
+      BirnetThread *thread = NULL;
       /* guard caller against receiver messing with value */
       for (ring = value_ring; ring; ring = sfi_ring_next (ring, value_ring))
         target = sfi_ring_append (target, sfi_value_clone_deep (ring->data));
 
-      SFI_SPIN_LOCK (&link->mutex);
+      sfi_mutex_lock (&link->mutex);
       if (first)
 	link->p1queue = sfi_ring_concat (link->p1queue, target);
       else
@@ -401,7 +400,7 @@ sfi_com_port_send_bulk (SfiComPort   *port,
 	sfi_cond_signal (&link->wcond);
       else
 	thread = first ? link->thread2 : link->thread1;
-      SFI_SPIN_UNLOCK (&link->mutex);
+      sfi_mutex_unlock (&link->mutex);
       MASS_DEBUG ("[%s: sent values]", port->ident);
       if (thread)
 	sfi_thread_wakeup (thread);
@@ -575,7 +574,7 @@ sfi_com_port_recv_intern (SfiComPort *port,
     {
       SfiComPortLink *link = port->link;
       
-      SFI_SPIN_LOCK (&link->mutex);
+      sfi_mutex_lock (&link->mutex);
     refetch:
       if (port == link->port1)
 	port->rvalues = link->p2queue, link->p2queue = NULL;
@@ -588,7 +587,7 @@ sfi_com_port_recv_intern (SfiComPort *port,
 	  link->waiting = FALSE;
 	  goto refetch;
 	}
-      SFI_SPIN_UNLOCK (&link->mutex);
+      sfi_mutex_unlock (&link->mutex);
     }
   else if (!port->rvalues)
     {
