@@ -16,11 +16,11 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include "sfidl-clientc.h"
-#include "sfidl-factory.h"
-#include "sfidl-namespace.h"
-#include "sfidl-options.h"
-#include "sfidl-parser.h"
+#include "sfidl-clientc.hh"
+#include "sfidl-factory.hh"
+#include "sfidl-namespace.hh"
+#include "sfidl-options.hh"
+#include "sfidl-parser.hh"
 #include <stdio.h>
 
 using namespace Sfidl;
