@@ -20,6 +20,7 @@
 #define __SFI_GLUE_H__
 
 #include <sfi/sfiprimitives.h>
+#include <sfi/sfiring.h>
 #include <sfi/sfiparams.h>
 
 G_BEGIN_DECLS
@@ -49,7 +50,6 @@ void		sfi_glue_iface_unref	(SfiGlueIFace	*iface);
 typedef struct {
   guint        ref_count;
   gchar       *name;
-  gchar       *blurb;
   gchar       *help;
   gchar       *authors;
   gchar       *license;
