@@ -16,7 +16,7 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include "bsecxxapi.h"
+#include "bsecxxapi.hh"
 #include <bse/bse.h>
 #include <unistd.h>
 #include <sys/time.h>
@@ -39,10 +39,8 @@ gettime ()
 int main(int argc, char **argv)
 {
   std::set_terminate (__gnu_cxx::__verbose_terminate_handler);
-  g_thread_init (NULL);
-  sfi_init ();
+  bse_init_async (&argc, &argv, "Perftest", NULL);
   sfi_msg_allow ("misc");
-  bse_init_async (&argc, &argv, NULL);
   bse_context = bse_init_glue_context (argv[0]);
 
   sfi_glue_context_push (bse_context);
@@ -53,7 +51,7 @@ int main(int argc, char **argv)
   double start = gettime ();
 
   for(int i=0; i < max_calls; i++)
-    note_to_freq (60, 0);
+    note_to_freq (MUSICAL_TUNING_12_TET, 60, 0);
 
   double t = gettime () - start;
   printf ("%f seconds for %d invocations => %f invocations/second, %f milli seconds per invocation\n",
